Class: Aws::VerifiedPermissions::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::VerifiedPermissions::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-verifiedpermissions/client.rb
Overview
An API client for VerifiedPermissions. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::VerifiedPermissions::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_policy(params = {}) ⇒ Types::BatchGetPolicyOutput
Retrieves information about a group (batch) of policies.
-
#batch_is_authorized(params = {}) ⇒ Types::BatchIsAuthorizedOutput
Makes a series of decisions about multiple authorization requests for one principal or resource.
-
#batch_is_authorized_with_token(params = {}) ⇒ Types::BatchIsAuthorizedWithTokenOutput
Makes a series of decisions about multiple authorization requests for one token.
-
#create_identity_source(params = {}) ⇒ Types::CreateIdentitySourceOutput
Adds an identity source to a policy store–an Amazon Cognito user pool or OpenID Connect (OIDC) identity provider (IdP).
-
#create_policy(params = {}) ⇒ Types::CreatePolicyOutput
Creates a Cedar policy and saves it in the specified policy store.
-
#create_policy_store(params = {}) ⇒ Types::CreatePolicyStoreOutput
Creates a policy store.
-
#create_policy_store_alias(params = {}) ⇒ Types::CreatePolicyStoreAliasOutput
Creates a policy store alias for the specified policy store.
-
#create_policy_template(params = {}) ⇒ Types::CreatePolicyTemplateOutput
Creates a policy template.
-
#delete_identity_source(params = {}) ⇒ Struct
Deletes an identity source that references an identity provider (IdP) such as Amazon Cognito.
-
#delete_policy(params = {}) ⇒ Struct
Deletes the specified policy from the policy store.
-
#delete_policy_store(params = {}) ⇒ Struct
Deletes the specified policy store.
-
#delete_policy_store_alias(params = {}) ⇒ Struct
Deletes the specified policy store alias.
-
#delete_policy_template(params = {}) ⇒ Struct
Deletes the specified policy template from the policy store.
-
#get_identity_source(params = {}) ⇒ Types::GetIdentitySourceOutput
Retrieves the details about the specified identity source.
-
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Retrieves information about the specified policy.
-
#get_policy_store(params = {}) ⇒ Types::GetPolicyStoreOutput
Retrieves details about a policy store.
-
#get_policy_store_alias(params = {}) ⇒ Types::GetPolicyStoreAliasOutput
Retrieves details about the specified policy store alias.
-
#get_policy_template(params = {}) ⇒ Types::GetPolicyTemplateOutput
Retrieve the details for the specified policy template in the specified policy store.
-
#get_schema(params = {}) ⇒ Types::GetSchemaOutput
Retrieve the details for the specified schema in the specified policy store.
-
#is_authorized(params = {}) ⇒ Types::IsAuthorizedOutput
Makes an authorization decision about a service request described in the parameters.
-
#is_authorized_with_token(params = {}) ⇒ Types::IsAuthorizedWithTokenOutput
Makes an authorization decision about a service request described in the parameters.
-
#list_identity_sources(params = {}) ⇒ Types::ListIdentitySourcesOutput
Returns a paginated list of all of the identity sources defined in the specified policy store.
-
#list_policies(params = {}) ⇒ Types::ListPoliciesOutput
Returns a paginated list of all policies stored in the specified policy store.
-
#list_policy_store_aliases(params = {}) ⇒ Types::ListPolicyStoreAliasesOutput
Returns a paginated list of all policy store aliases in the calling Amazon Web Services account.
-
#list_policy_stores(params = {}) ⇒ Types::ListPolicyStoresOutput
Returns a paginated list of all policy stores in the calling Amazon Web Services account.
-
#list_policy_templates(params = {}) ⇒ Types::ListPolicyTemplatesOutput
Returns a paginated list of all policy templates in the specified policy store.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified Amazon Verified Permissions resource.
-
#put_schema(params = {}) ⇒ Types::PutSchemaOutput
Creates or updates the policy schema in the specified policy store.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Amazon Verified Permissions resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Amazon Verified Permissions resource.
-
#update_identity_source(params = {}) ⇒ Types::UpdateIdentitySourceOutput
Updates the specified identity source to use a new identity provider (IdP), or to change the mapping of identities from the IdP to a different principal entity type.
-
#update_policy(params = {}) ⇒ Types::UpdatePolicyOutput
Modifies a Cedar static policy in the specified policy store.
-
#update_policy_store(params = {}) ⇒ Types::UpdatePolicyStoreOutput
Modifies the validation setting for a policy store.
-
#update_policy_template(params = {}) ⇒ Types::UpdatePolicyTemplateOutput
Updates the specified policy template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5017 5018 5019 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 5017 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5020 5021 5022 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 5020 def errors_module Errors end |
Instance Method Details
#batch_get_policy(params = {}) ⇒ Types::BatchGetPolicyOutput
Retrieves information about a group (batch) of policies.
<note markdown=“1”> The ‘BatchGetPolicy` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘verifiedpermissions:GetPolicy` in their IAM policies.
</note>
666 667 668 669 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 666 def batch_get_policy(params = {}, = {}) req = build_request(:batch_get_policy, params) req.send_request() end |
#batch_is_authorized(params = {}) ⇒ Types::BatchIsAuthorizedOutput
Makes a series of decisions about multiple authorization requests for one principal or resource. Each request contains the equivalent content of an ‘IsAuthorized` request: principal, action, resource, and context. Either the `principal` or the `resource` parameter must be identical across all requests. For example, Verified Permissions won’t evaluate a pair of requests where ‘bob` views `photo1` and `alice` views `photo2`. Authorization of `bob` to view `photo1` and `photo2`, or `bob` and `alice` to view `photo1`, are valid batches.
The request is evaluated against all policies in the specified policy store that match the entities that you declare. The result of the decisions is a series of ‘Allow` or `Deny` responses, along with the IDs of the policies that produced each decision.
The ‘entities` of a `BatchIsAuthorized` API request can contain up to 100 principals and up to 100 resources. The `requests` of a `BatchIsAuthorized` API request can contain up to 30 requests.
<note markdown=“1”> The ‘BatchIsAuthorized` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘verifiedpermissions:IsAuthorized` in their IAM policies.
</note>
995 996 997 998 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 995 def (params = {}, = {}) req = build_request(:batch_is_authorized, params) req.send_request() end |
#batch_is_authorized_with_token(params = {}) ⇒ Types::BatchIsAuthorizedWithTokenOutput
Makes a series of decisions about multiple authorization requests for one token. The principal in this request comes from an external identity source in the form of an identity or access token, formatted as a [JSON web token (JWT)]. The information in the parameters can also define additional context that Verified Permissions can include in the evaluations.
The request is evaluated against all policies in the specified policy store that match the entities that you provide in the entities declaration and in the token. The result of the decisions is a series of ‘Allow` or `Deny` responses, along with the IDs of the policies that produced each decision.
The ‘entities` of a `BatchIsAuthorizedWithToken` API request can contain up to 100 resources and up to 99 user groups. The `requests` of a `BatchIsAuthorizedWithToken` API request can contain up to 30 requests.
<note markdown=“1”> The ‘BatchIsAuthorizedWithToken` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘verifiedpermissions:IsAuthorizedWithToken` in their IAM policies.
</note>
1323 1324 1325 1326 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 1323 def (params = {}, = {}) req = build_request(:batch_is_authorized_with_token, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4990 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::VerifiedPermissions') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-verifiedpermissions' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#create_identity_source(params = {}) ⇒ Types::CreateIdentitySourceOutput
Adds an identity source to a policy store–an Amazon Cognito user pool or OpenID Connect (OIDC) identity provider (IdP).
After you create an identity source, you can use the identities provided by the IdP as proxies for the principal in authorization queries that use the [IsAuthorizedWithToken] or
- BatchIsAuthorizedWithToken][2
-
API operations. These identities take
the form of tokens that contain claims about the user, such as IDs, attributes and group memberships. Identity sources provide identity (ID) tokens and access tokens. Verified Permissions derives information about your user and session from token claims. Access tokens provide action ‘context` to your policies, and ID tokens provide principal `Attributes`.
Tokens from an identity source user continue to be usable until they expire. Token revocation and resource deletion have no effect on the validity of a token in your policy store
<note markdown=“1”> To reference a user from this identity source in your Cedar policies, refer to the following syntax examples.
* Amazon Cognito user pool: `Namespace::[Entity type]::[User pool
ID]|[user principal attribute]`, for example
`MyCorp::User::us-east-1_EXAMPLE|a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`.
-
OpenID Connect (OIDC) provider: ‘Namespace::[Entity type]::|[user principal attribute]`, for example `MyCorp::User::MyOIDCProvider|a1b2c3d4-5678-90ab-cdef-EXAMPLE22222`.
</note>
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorizedWithToken.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_BatchIsAuthorizedWithToken.html
1507 1508 1509 1510 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 1507 def create_identity_source(params = {}, = {}) req = build_request(:create_identity_source, params) req.send_request() end |
#create_policy(params = {}) ⇒ Types::CreatePolicyOutput
Creates a Cedar policy and saves it in the specified policy store. You can create either a static policy or a policy linked to a policy template.
-
To create a static policy, provide the Cedar policy text in the ‘StaticPolicy` section of the `PolicyDefinition`.
-
To create a policy that is dynamically linked to a policy template, specify the policy template ID and the principal and resource to associate with this policy in the ‘templateLinked` section of the `PolicyDefinition`. If the policy template is ever updated, any policies linked to the policy template automatically use the updated template.
<note markdown=“1”> Creating a policy causes it to be validated against the schema in the policy store. If the policy doesn’t pass validation, the operation fails and the policy isn’t stored.
</note>
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
1728 1729 1730 1731 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 1728 def create_policy(params = {}, = {}) req = build_request(:create_policy, params) req.send_request() end |
#create_policy_store(params = {}) ⇒ Types::CreatePolicyStoreOutput
Creates a policy store. A policy store is a container for policy resources.
<note markdown=“1”> Although [Cedar supports multiple namespaces], Verified Permissions currently supports only one namespace per policy store.
</note>
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
1905 1906 1907 1908 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 1905 def create_policy_store(params = {}, = {}) req = build_request(:create_policy_store, params) req.send_request() end |
#create_policy_store_alias(params = {}) ⇒ Types::CreatePolicyStoreAliasOutput
Creates a policy store alias for the specified policy store. A policy store alias is an alternative identifier that you can use to reference a policy store in API operations.
This operation is idempotent. If multiple CreatePolicyStoreAlias requests are made where the ‘aliasName` and `policyStoreId` fields are the same between the requests, subsequent requests will be ignored. For each duplicate CreatePolicyStoreAlias request, a Success response will be returned and a new policy store alias will not be created.
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
1988 1989 1990 1991 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 1988 def create_policy_store_alias(params = {}, = {}) req = build_request(:create_policy_store_alias, params) req.send_request() end |
#create_policy_template(params = {}) ⇒ Types::CreatePolicyTemplateOutput
Creates a policy template. A template can use placeholders for the principal and resource. A template must be instantiated into a policy by associating it with specific principals and resources to use for the placeholders. That instantiated policy can then be considered in authorization decisions. The instantiated policy works identically to any other policy, except that it is dynamically linked to the template. If the template changes, then any policies that are linked to that template are immediately updated as well.
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
2117 2118 2119 2120 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2117 def create_policy_template(params = {}, = {}) req = build_request(:create_policy_template, params) req.send_request() end |
#delete_identity_source(params = {}) ⇒ Struct
Deletes an identity source that references an identity provider (IdP) such as Amazon Cognito. After you delete the identity source, you can no longer use tokens for identities from that identity source to represent principals in authorization queries made using [IsAuthorizedWithToken]. operations.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorizedWithToken.html
2179 2180 2181 2182 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2179 def delete_identity_source(params = {}, = {}) req = build_request(:delete_identity_source, params) req.send_request() end |
#delete_policy(params = {}) ⇒ Struct
Deletes the specified policy from the policy store.
This operation is idempotent; if you specify a policy that doesn’t exist, the request response returns a successful ‘HTTP 200` status code.
2244 2245 2246 2247 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2244 def delete_policy(params = {}, = {}) req = build_request(:delete_policy, params) req.send_request() end |
#delete_policy_store(params = {}) ⇒ Struct
Deletes the specified policy store.
This operation is idempotent. If you specify a policy store that does not exist, the request response will still return a successful HTTP 200 status code.
2288 2289 2290 2291 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2288 def delete_policy_store(params = {}, = {}) req = build_request(:delete_policy_store, params) req.send_request() end |
#delete_policy_store_alias(params = {}) ⇒ Struct
Deletes the specified policy store alias.
This operation is idempotent. If you specify a policy store alias that does not exist, the request response will still return a successful HTTP 200 status code.
When a policy store alias is deleted, it enters the ‘PendingDeletion` state. When a policy store alias is in the `PendingDeletion` state, new policy store aliases cannot be created with the same name. If the policy store alias is used in an API that has a `policyStoreId` field, the operation will fail with a `ResourceNotFound` exception.
2337 2338 2339 2340 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2337 def delete_policy_store_alias(params = {}, = {}) req = build_request(:delete_policy_store_alias, params) req.send_request() end |
#delete_policy_template(params = {}) ⇒ Struct
Deletes the specified policy template from the policy store.
This operation also deletes any policies that were created from the specified policy template. Those policies are immediately removed from all future API responses, and are asynchronously deleted from the policy store.
2404 2405 2406 2407 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2404 def delete_policy_template(params = {}, = {}) req = build_request(:delete_policy_template, params) req.send_request() end |
#get_identity_source(params = {}) ⇒ Types::GetIdentitySourceOutput
Retrieves the details about the specified identity source.
2507 2508 2509 2510 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2507 def get_identity_source(params = {}, = {}) req = build_request(:get_identity_source, params) req.send_request() end |
#get_policy(params = {}) ⇒ Types::GetPolicyOutput
Retrieves information about the specified policy.
2650 2651 2652 2653 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2650 def get_policy(params = {}, = {}) req = build_request(:get_policy, params) req.send_request() end |
#get_policy_store(params = {}) ⇒ Types::GetPolicyStoreOutput
Retrieves details about a policy store.
2775 2776 2777 2778 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2775 def get_policy_store(params = {}, = {}) req = build_request(:get_policy_store, params) req.send_request() end |
#get_policy_store_alias(params = {}) ⇒ Types::GetPolicyStoreAliasOutput
Retrieves details about the specified policy store alias.
2834 2835 2836 2837 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2834 def get_policy_store_alias(params = {}, = {}) req = build_request(:get_policy_store_alias, params) req.send_request() end |
#get_policy_template(params = {}) ⇒ Types::GetPolicyTemplateOutput
Retrieve the details for the specified policy template in the specified policy store.
2941 2942 2943 2944 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 2941 def get_policy_template(params = {}, = {}) req = build_request(:get_policy_template, params) req.send_request() end |
#get_schema(params = {}) ⇒ Types::GetSchemaOutput
Retrieve the details for the specified schema in the specified policy store.
3015 3016 3017 3018 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 3015 def get_schema(params = {}, = {}) req = build_request(:get_schema, params) req.send_request() end |
#is_authorized(params = {}) ⇒ Types::IsAuthorizedOutput
Makes an authorization decision about a service request described in the parameters. The information in the parameters can also define additional context that Verified Permissions can include in the evaluation. The request is evaluated against all matching policies in the specified policy store. The result of the decision is either ‘Allow` or `Deny`, along with a list of the policies that resulted in the decision.
3227 3228 3229 3230 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 3227 def (params = {}, = {}) req = build_request(:is_authorized, params) req.send_request() end |
#is_authorized_with_token(params = {}) ⇒ Types::IsAuthorizedWithTokenOutput
Makes an authorization decision about a service request described in the parameters. The principal in this request comes from an external identity source in the form of an identity token formatted as a [JSON web token (JWT)]. The information in the parameters can also define additional context that Verified Permissions can include in the evaluation. The request is evaluated against all matching policies in the specified policy store. The result of the decision is either ‘Allow` or `Deny`, along with a list of the policies that resulted in the decision.
Verified Permissions validates each token that is specified in a request by checking its expiration date and its signature.
Tokens from an identity source user continue to be usable until they expire. Token revocation and resource deletion have no effect on the validity of a token in your policy store
3446 3447 3448 3449 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 3446 def (params = {}, = {}) req = build_request(:is_authorized_with_token, params) req.send_request() end |
#list_identity_sources(params = {}) ⇒ Types::ListIdentitySourcesOutput
Returns a paginated list of all of the identity sources defined in the specified policy store.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3580 3581 3582 3583 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 3580 def list_identity_sources(params = {}, = {}) req = build_request(:list_identity_sources, params) req.send_request() end |
#list_policies(params = {}) ⇒ Types::ListPoliciesOutput
Returns a paginated list of all policies stored in the specified policy store.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3851 3852 3853 3854 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 3851 def list_policies(params = {}, = {}) req = build_request(:list_policies, params) req.send_request() end |
#list_policy_store_aliases(params = {}) ⇒ Types::ListPolicyStoreAliasesOutput
Returns a paginated list of all policy store aliases in the calling Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3982 3983 3984 3985 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 3982 def list_policy_store_aliases(params = {}, = {}) req = build_request(:list_policy_store_aliases, params) req.send_request() end |
#list_policy_stores(params = {}) ⇒ Types::ListPolicyStoresOutput
Returns a paginated list of all policy stores in the calling Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4063 4064 4065 4066 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4063 def list_policy_stores(params = {}, = {}) req = build_request(:list_policy_stores, params) req.send_request() end |
#list_policy_templates(params = {}) ⇒ Types::ListPolicyTemplatesOutput
Returns a paginated list of all policy templates in the specified policy store.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4170 4171 4172 4173 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4170 def list_policy_templates(params = {}, = {}) req = build_request(:list_policy_templates, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified Amazon Verified Permissions resource. In Verified Permissions, policy stores can be tagged.
4218 4219 4220 4221 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4218 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_schema(params = {}) ⇒ Types::PutSchemaOutput
Creates or updates the policy schema in the specified policy store. The schema is used to validate any Cedar policies and policy templates submitted to the policy store. Any changes to the schema validate only policies and templates submitted after the schema change. Existing policies and templates are not re-evaluated against the changed schema. If you later update a policy, then it is evaluated against the new schema at that time.
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
4316 4317 4318 4319 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4316 def put_schema(params = {}, = {}) req = build_request(:put_schema, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified Amazon Verified Permissions resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In Verified Permissions, policy stores can be tagged.
Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the TagResource action with a resource that already has tags. If you specify a new tag key, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
You can associate as many as 50 tags with a resource.
4377 4378 4379 4380 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4377 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified Amazon Verified Permissions resource. In Verified Permissions, policy stores can be tagged.
4422 4423 4424 4425 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4422 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_identity_source(params = {}) ⇒ Types::UpdateIdentitySourceOutput
Updates the specified identity source to use a new identity provider (IdP), or to change the mapping of identities from the IdP to a different principal entity type.
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
4546 4547 4548 4549 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4546 def update_identity_source(params = {}, = {}) req = build_request(:update_identity_source, params) req.send_request() end |
#update_policy(params = {}) ⇒ Types::UpdatePolicyOutput
Modifies a Cedar static policy in the specified policy store. You can change only certain elements of the [UpdatePolicyDefinition] parameter. You can directly update only static policies. To change a template-linked policy, you must update the template instead, using [UpdatePolicyTemplate].
<note markdown=“1”> * If policy validation is enabled in the policy store, then updating a
static policy causes Verified Permissions to validate the policy
against the schema in the policy store. If the updated static policy
doesn't pass validation, the operation fails and the update isn't
stored.
-
When you edit a static policy, you can change only certain elements of a static policy:
-
The action referenced by the policy.
-
A condition clause, such as when and unless.
You can’t change these elements of a static policy:
-
Changing a policy from a static policy to a template-linked policy.
-
Changing the effect of a static policy from permit or forbid.
-
The principal referenced by a static policy.
-
The resource referenced by a static policy.
-
-
To update a template-linked policy, you must update the template instead.
</note>
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdatePolicyInput.html#amazonverifiedpermissions-UpdatePolicy-request-UpdatePolicyDefinition [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdatePolicyTemplate.html
4742 4743 4744 4745 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4742 def update_policy(params = {}, = {}) req = build_request(:update_policy, params) req.send_request() end |
#update_policy_store(params = {}) ⇒ Types::UpdatePolicyStoreOutput
Modifies the validation setting for a policy store.
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
4837 4838 4839 4840 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4837 def update_policy_store(params = {}, = {}) req = build_request(:update_policy_store, params) req.send_request() end |
#update_policy_template(params = {}) ⇒ Types::UpdatePolicyTemplateOutput
Updates the specified policy template. You can update only the description and the some elements of the [policyBody].
Changes you make to the policy template content are immediately (within the constraints of eventual consistency) reflected in authorization decisions that involve all template-linked policies instantiated from this template.
<note markdown=“1”> Verified Permissions is <a href=“https://wikipedia.org/wiki/Eventual_consistency”>eventually consistent</a> . It can take a few seconds for a new or changed element to propagate through the service and be visible in the results of other Verified Permissions operations.
</note>
4981 4982 4983 4984 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 4981 def update_policy_template(params = {}, = {}) req = build_request(:update_policy_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5010 5011 5012 |
# File 'lib/aws-sdk-verifiedpermissions/client.rb', line 5010 def waiter_names [] end |