Class: Aws::VerifiedPermissions::Types::AttributeValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Note:

AttributeValue is a union - when making an API calls you must set exactly one of the members.

Note:

AttributeValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AttributeValue corresponding to the set member.

The value of an attribute.

Contains information about the runtime context for a request for which an authorization decision is made.

This data type is used as a member of the [ContextDefinition] structure which is used as a request parameter for the [IsAuthorized], [BatchIsAuthorized], and

IsAuthorizedWithToken][4

operations.

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ContextDefinition.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorized.html [3]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_BatchIsAuthorized.html [4]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorizedWithToken.html

Defined Under Namespace

Classes: Boolean, Datetime, Decimal, Duration, EntityIdentifier, Ipaddr, Long, Record, Set, String, Unknown

Constant Summary collapse

SENSITIVE =
[:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]

Instance Attribute Summary collapse

Instance Attribute Details

#booleanBoolean

An attribute value of [Boolean] type.

Example: ‘true`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-bool

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#datetimeString

An attribute value of [datetime] type.

Example: ‘“2024-10-15T11:35:00Z”`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-datetime

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#decimalString

An attribute value of [decimal] type.

Example: ‘“1.1”`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-decimal

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#durationString

An attribute value of [duration] type.

Example: ‘“1h30m”`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-duration

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#entity_identifierTypes::EntityIdentifier

An attribute value of type [EntityIdentifier].

Example: ‘{ “entityId”: “alice”, “entityType”: “User” }`

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_EntityIdentifier.html



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#ipaddrString

An attribute value of [ipaddr] type.

Example: ‘“192.168.1.100”`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-ipaddr

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#longInteger

An attribute value of [Long] type.

Example: ‘0`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-long

Returns:

  • (Integer)


182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#recordHash<String,Types::AttributeValue>

An attribute value of [Record] type.

Example: ‘{ “keyName”: { } }`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-record

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#setArray<Types::AttributeValue>

An attribute value of [Set] type.

Example: ‘[ { ] }`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-set

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#stringString

An attribute value of [String] type.

Example: ‘“abc”`

[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-string

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

class AttributeValue < Struct.new(
  :boolean,
  :entity_identifier,
  :long,
  :string,
  :set,
  :record,
  :ipaddr,
  :decimal,
  :datetime,
  :duration,
  :unknown)
  SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
  include Aws::Structure
  include Aws::Structure::Union

  class Boolean < AttributeValue; end
  class EntityIdentifier < AttributeValue; end
  class Long < AttributeValue; end
  class String < AttributeValue; end
  class Set < AttributeValue; end
  class Record < AttributeValue; end
  class Ipaddr < AttributeValue; end
  class Decimal < AttributeValue; end
  class Datetime < AttributeValue; end
  class Duration < AttributeValue; end
  class Unknown < AttributeValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



182
183
184
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182

def unknown
  @unknown
end