Class: Aws::VerifiedPermissions::Types::BatchGetPolicyInputItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Information about a policy that you include in a ‘BatchGetPolicy` API request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_idString

The identifier of the policy you want information about.

You can use the policy name in place of the policy ID. When using a name, prefix it with ‘name/`. For example:

  • ID: ‘SPEXAMPLEabcdefg111111`

  • Name: ‘name/example-policy`

Returns:

  • (String)


275
276
277
278
279
280
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 275

class BatchGetPolicyInputItem < Struct.new(
  :policy_store_id,
  :policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

The identifier of the policy store where the policy you want information about is stored.

Returns:

  • (String)


275
276
277
278
279
280
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 275

class BatchGetPolicyInputItem < Struct.new(
  :policy_store_id,
  :policy_id)
  SENSITIVE = []
  include Aws::Structure
end