Class: Aws::VerifiedPermissions::Types::BatchIsAuthorizedInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entitiesTypes::EntitiesDefinition

(Optional) Specifies the list of resources and principals and their associated attributes that Verified Permissions can examine when evaluating the policies. These additional entities and their attributes can be referenced and checked by conditional elements in the policies in the specified policy store.

<note markdown=“1”> You can include only principal and resource entities in this parameter; you can’t include actions. You must specify actions in the schema.

</note>


392
393
394
395
396
397
398
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 392

class BatchIsAuthorizedInput < Struct.new(
  :policy_store_id,
  :entities,
  :requests)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store. Policies in this policy store will be used to make the authorization decisions for the input.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


392
393
394
395
396
397
398
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 392

class BatchIsAuthorizedInput < Struct.new(
  :policy_store_id,
  :entities,
  :requests)
  SENSITIVE = []
  include Aws::Structure
end

#requestsArray<Types::BatchIsAuthorizedInputItem>

An array of up to 30 requests that you want Verified Permissions to evaluate.



392
393
394
395
396
397
398
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 392

class BatchIsAuthorizedInput < Struct.new(
  :policy_store_id,
  :entities,
  :requests)
  SENSITIVE = []
  include Aws::Structure
end