Class: Aws::VerifiedPermissions::Types::CreatePolicyStoreAliasInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_nameString

Specifies the name of the policy store alias to create. The name must be unique within your Amazon Web Services account and Amazon Web Services Region.

The alias name must always be prefixed with policy-store-alias/.

Returns:

  • (String)


1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1528

class CreatePolicyStoreAliasInput < Struct.new(
  :alias_name,
  :policy_store_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store to associate with the alias.

The associated policy store must be specified using its ID. The alias name cannot be used.

Returns:

  • (String)


1528
1529
1530
1531
1532
1533
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1528

class CreatePolicyStoreAliasInput < Struct.new(
  :alias_name,
  :policy_store_id)
  SENSITIVE = []
  include Aws::Structure
end