Class: Aws::VerifiedPermissions::Types::CreatePolicyStoreAliasOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::CreatePolicyStoreAliasOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_arn ⇒ String
The Amazon Resource Name (ARN) of the policy store alias.
-
#alias_name ⇒ String
The name of the policy store alias.
-
#created_at ⇒ Time
The date and time the policy store alias was created.
-
#policy_store_id ⇒ String
The ID of the policy store associated with the alias.
Instance Attribute Details
#alias_arn ⇒ String
The Amazon Resource Name (ARN) of the policy store alias.
1553 1554 1555 1556 1557 1558 1559 1560 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1553 class CreatePolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at) SENSITIVE = [] include Aws::Structure end |
#alias_name ⇒ String
The name of the policy store alias.
1553 1554 1555 1556 1557 1558 1559 1560 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1553 class CreatePolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the policy store alias was created.
1553 1554 1555 1556 1557 1558 1559 1560 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1553 class CreatePolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the policy store associated with the alias.
1553 1554 1555 1556 1557 1558 1559 1560 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1553 class CreatePolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at) SENSITIVE = [] include Aws::Structure end |