Class: Aws::VerifiedPermissions::Types::CreatePolicyStoreInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Specifies a unique, case-sensitive ID that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value..

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an ConflictException error.

Verified Permissions recognizes a ClientToken for eight hours. After eight hours, the next request with the same parameters performs the operation again regardless of the value of ClientToken.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1634

class CreatePolicyStoreInput < Struct.new(
  :client_token,
  :validation_settings,
  :description,
  :deletion_protection,
  :encryption_settings,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#deletion_protectionString

Specifies whether the policy store can be deleted. If enabled, the policy store can't be deleted.

The default state is DISABLED.

Returns:

  • (String)


1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1634

class CreatePolicyStoreInput < Struct.new(
  :client_token,
  :validation_settings,
  :description,
  :deletion_protection,
  :encryption_settings,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

Descriptive text that you can provide to help with identification of the current policy store.

Returns:

  • (String)


1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1634

class CreatePolicyStoreInput < Struct.new(
  :client_token,
  :validation_settings,
  :description,
  :deletion_protection,
  :encryption_settings,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#encryption_settingsTypes::EncryptionSettings

Specifies the encryption settings used to encrypt the policy store and their child resources. Allows for the ability to use a customer owned KMS key for encryption of data.

This is an optional field to be used when providing a customer-managed KMS key for encryption.



1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1634

class CreatePolicyStoreInput < Struct.new(
  :client_token,
  :validation_settings,
  :description,
  :deletion_protection,
  :encryption_settings,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The list of key-value pairs to associate with the policy store.

Returns:

  • (Hash<String,String>)


1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1634

class CreatePolicyStoreInput < Struct.new(
  :client_token,
  :validation_settings,
  :description,
  :deletion_protection,
  :encryption_settings,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#validation_settingsTypes::ValidationSettings

Specifies the validation setting for this policy store.

Currently, the only valid and required value is Mode.

We recommend that you turn on STRICT mode only after you define a schema. If a schema doesn't exist, then STRICT mode causes any policy to fail validation, and Verified Permissions rejects the policy. You can turn off validation by using the UpdatePolicyStore. Then, when you have a schema defined, use UpdatePolicyStore again to turn validation back on.



1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1634

class CreatePolicyStoreInput < Struct.new(
  :client_token,
  :validation_settings,
  :description,
  :deletion_protection,
  :encryption_settings,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end