Class: Aws::VerifiedPermissions::Types::CreatePolicyTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::CreatePolicyTemplateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :statement]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Specifies a unique, case-sensitive ID that you provide to ensure the idempotency of the request.
-
#description ⇒ String
Specifies a description for the policy template.
-
#name ⇒ String
Specifies a name for the policy template that is unique among all policy templates within the policy store.
-
#policy_store_id ⇒ String
The ID of the policy store in which to create the policy template.
-
#statement ⇒ String
Specifies the content that you want to use for the new policy template, written in the Cedar policy language.
Instance Attribute Details
#client_token ⇒ String
Specifies a unique, case-sensitive ID that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a [UUID type of value.].
If you don’t provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ‘ClientToken`, but with different parameters, the retry fails with an `ConflictException` error.
Verified Permissions recognizes a ‘ClientToken` for eight hours. After eight hours, the next request with the same parameters performs the operation again regardless of the value of `ClientToken`.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1739 class CreatePolicyTemplateInput < Struct.new( :client_token, :policy_store_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#description ⇒ String
Specifies a description for the policy template.
1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1739 class CreatePolicyTemplateInput < Struct.new( :client_token, :policy_store_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#name ⇒ String
Specifies a name for the policy template that is unique among all policy templates within the policy store. You can use the name in place of the policy template ID in API operations that reference the policy template. The name must be prefixed with ‘name/`.
If you specify a name that is already associated with another policy template in the policy store, you receive a ‘ConflictException` error.
1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1739 class CreatePolicyTemplateInput < Struct.new( :client_token, :policy_store_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the policy store in which to create the policy template.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1739 class CreatePolicyTemplateInput < Struct.new( :client_token, :policy_store_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#statement ⇒ String
Specifies the content that you want to use for the new policy template, written in the Cedar policy language.
1739 1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1739 class CreatePolicyTemplateInput < Struct.new( :client_token, :policy_store_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |