Class: Aws::VerifiedPermissions::Types::DeleteIdentitySourceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_source_idString

Specifies the ID of the identity source that you want to delete.

Returns:

  • (String)


1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1800

class DeleteIdentitySourceInput < Struct.new(
  :policy_store_id,
  :identity_source_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store that contains the identity source that you want to delete.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1800

class DeleteIdentitySourceInput < Struct.new(
  :policy_store_id,
  :identity_source_id)
  SENSITIVE = []
  include Aws::Structure
end