Class: Aws::VerifiedPermissions::Types::DeletePolicyStoreAliasInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_nameString

Specifies the name of the policy store alias that you want to delete.

<note markdown=“1”> The alias name must always be prefixed with ‘policy-store-alias/`.

</note>

Returns:

  • (String)


1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1876

class DeletePolicyStoreAliasInput < Struct.new(
  :alias_name,
  :deletion_mode)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_modeString

Specifies the deletion mode for the policy store alias. The valid values are:

  • SoftDelete – The policy store alias enters the ‘PendingDeletion` state. This is the default behavior when no `deletionMode` is specified.

  • HardDelete – The policy store alias is immediately deleted, bypassing the ‘PendingDeletion` state.

Returns:

  • (String)


1876
1877
1878
1879
1880
1881
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1876

class DeletePolicyStoreAliasInput < Struct.new(
  :alias_name,
  :deletion_mode)
  SENSITIVE = []
  include Aws::Structure
end