Class: Aws::VerifiedPermissions::Types::EncryptionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::EncryptionSettings
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
EncryptionSettings is a union - when making an API calls you must set exactly one of the members.
A structure that contains the encryption configuration for the policy store and child resources.
This data type is used as a request parameter in the
- CreatePolicyStore][1
-
operation.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_CreatePolicyStore.html
Direct Known Subclasses
Defined Under Namespace
Classes: Default, KmsEncryptionSettings, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default ⇒ Types::Unit
This is the default encryption setting.
-
#kms_encryption_settings ⇒ Types::KmsEncryptionSettings
The KMS encryption settings for this policy store to encrypt data with.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#default ⇒ Types::Unit
This is the default encryption setting. The policy store uses an Amazon Web Services owned key for encrypting data.
2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2005 class EncryptionSettings < Struct.new( :kms_encryption_settings, :default, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsEncryptionSettings < EncryptionSettings; end class Default < EncryptionSettings; end class Unknown < EncryptionSettings; end end |
#kms_encryption_settings ⇒ Types::KmsEncryptionSettings
The KMS encryption settings for this policy store to encrypt data with. It will contain the customer-managed KMS key, and a user-defined encryption context.
2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2005 class EncryptionSettings < Struct.new( :kms_encryption_settings, :default, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsEncryptionSettings < EncryptionSettings; end class Default < EncryptionSettings; end class Unknown < EncryptionSettings; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2005 2006 2007 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2005 def unknown @unknown end |