Class: Aws::VerifiedPermissions::Types::EncryptionState

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Note:

EncryptionState is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EncryptionState corresponding to the set member.

A structure that contains the encryption configuration for the policy store and child resources.

This data type is used as a response parameter field for the

GetPolicyStore][1

operation.

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_GetPolicyStore.html

Direct Known Subclasses

Default, KmsEncryptionState, Unknown

Defined Under Namespace

Classes: Default, KmsEncryptionState, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#defaultTypes::Unit

This is the default encryption state. The policy store is encrypted using an Amazon Web Services owned key.

Returns:



2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2043

class EncryptionState < Struct.new(
  :kms_encryption_state,
  :default,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KmsEncryptionState < EncryptionState; end
  class Default < EncryptionState; end
  class Unknown < EncryptionState; end
end

#kms_encryption_stateTypes::KmsEncryptionState

The KMS encryption settings currently configured for this policy store to encrypt data with. It contains the customer-managed KMS key, and a user-defined encryption context.



2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2043

class EncryptionState < Struct.new(
  :kms_encryption_state,
  :default,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KmsEncryptionState < EncryptionState; end
  class Default < EncryptionState; end
  class Unknown < EncryptionState; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2043
2044
2045
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2043

def unknown
  @unknown
end