Class: Aws::VerifiedPermissions::Types::EntityReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::EntityReference
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
EntityReference is a union - when making an API calls you must set exactly one of the members.
Contains information about a principal or resource that can be referenced in a Cedar policy.
This data type is used as part of the [PolicyFilter] structure that is used as a request parameter for the [ListPolicies] operation..
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_PolicyFilter.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicies.html
Direct Known Subclasses
Defined Under Namespace
Classes: Identifier, Unknown, Unspecified
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ Types::EntityIdentifier
The identifier of the entity.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#unspecified ⇒ Boolean
Used to indicate that a principal or resource is not specified.
Instance Attribute Details
#identifier ⇒ Types::EntityIdentifier
The identifier of the entity. It can consist of either an EntityType and EntityId, a principal, or a resource.
2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2203 class EntityReference < Struct.new( :unspecified, :identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Unspecified < EntityReference; end class Identifier < EntityReference; end class Unknown < EntityReference; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2203 2204 2205 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2203 def unknown @unknown end |
#unspecified ⇒ Boolean
Used to indicate that a principal or resource is not specified. This can be used to search for policies that are not associated with a specific principal or resource.
2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2203 class EntityReference < Struct.new( :unspecified, :identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Unspecified < EntityReference; end class Identifier < EntityReference; end class Unknown < EntityReference; end end |