Class: Aws::VerifiedPermissions::Types::GetPolicyInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_idString

Specifies the ID of the policy you want information about.

You can use the policy name in place of the policy ID. When using a name, prefix it with ‘name/`. For example:

  • ID: ‘SPEXAMPLEabcdefg111111`

  • Name: ‘name/example-policy`

Returns:

  • (String)


2345
2346
2347
2348
2349
2350
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2345

class GetPolicyInput < Struct.new(
  :policy_store_id,
  :policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store that contains the policy that you want information about.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


2345
2346
2347
2348
2349
2350
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2345

class GetPolicyInput < Struct.new(
  :policy_store_id,
  :policy_id)
  SENSITIVE = []
  include Aws::Structure
end