Class: Aws::VerifiedPermissions::Types::GetPolicyOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::GetPolicyOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::ActionIdentifier>
The action that a policy permits or forbids.
-
#created_date ⇒ Time
The date and time that the policy was originally created.
-
#definition ⇒ Types::PolicyDefinitionDetail
The definition of the requested policy.
-
#effect ⇒ String
The effect of the decision that a policy returns to an authorization request.
-
#last_updated_date ⇒ Time
The date and time that the policy was last updated.
-
#name ⇒ String
The name of the policy, if one was assigned when the policy was created or last updated.
-
#policy_id ⇒ String
The unique ID of the policy that you want information about.
-
#policy_store_id ⇒ String
The ID of the policy store that contains the policy that you want information about.
-
#policy_type ⇒ String
The type of the policy.
-
#principal ⇒ Types::EntityIdentifier
The principal specified in the policy’s scope.
-
#resource ⇒ Types::EntityIdentifier
The resource specified in the policy’s scope.
Instance Attribute Details
#actions ⇒ Array<Types::ActionIdentifier>
The action that a policy permits or forbids. For example, ‘[{“actionId”: “ViewPhoto”, “actionType”: “PhotoFlash::Action”, “SharePhoto”, “entityType”: “PhotoFlash::Action”]}`.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date and time that the policy was originally created.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ Types::PolicyDefinitionDetail
The definition of the requested policy.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#effect ⇒ String
The effect of the decision that a policy returns to an authorization request. For example, ‘“effect”: “Permit”`.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#last_updated_date ⇒ Time
The date and time that the policy was last updated.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the policy, if one was assigned when the policy was created or last updated.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#policy_id ⇒ String
The unique ID of the policy that you want information about.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the policy store that contains the policy that you want information about.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#policy_type ⇒ String
The type of the policy.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ Types::EntityIdentifier
The principal specified in the policy’s scope. This element isn’t included in the response when ‘Principal` isn’t present in the policy content.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::EntityIdentifier
The resource specified in the policy’s scope. This element isn’t included in the response when ‘Resource` isn’t present in the policy content.
2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2421 class GetPolicyOutput < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |