Class: Aws::VerifiedPermissions::Types::GetPolicyStoreAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::GetPolicyStoreAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
Specifies the name of the policy store alias that you want information about.
Instance Attribute Details
#alias_name ⇒ String
Specifies the name of the policy store alias that you want information about.
<note markdown=“1”> The alias name must always be prefixed with ‘policy-store-alias/`.
</note>
2435 2436 2437 2438 2439 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2435 class GetPolicyStoreAliasInput < Struct.new( :alias_name) SENSITIVE = [] include Aws::Structure end |