Class: Aws::VerifiedPermissions::Types::GetPolicyStoreAliasOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::GetPolicyStoreAliasOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_arn ⇒ String
The Amazon Resource Name (ARN) of the policy store alias.
-
#alias_name ⇒ String
The name of the policy store alias.
-
#created_at ⇒ Time
The date and time the policy store alias was created.
-
#policy_store_id ⇒ String
The ID of the policy store associated with the alias.
-
#state ⇒ String
The state of the policy store alias.
Instance Attribute Details
#alias_arn ⇒ String
The Amazon Resource Name (ARN) of the policy store alias.
2480 2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2480 class GetPolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#alias_name ⇒ String
The name of the policy store alias.
2480 2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2480 class GetPolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the policy store alias was created.
2480 2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2480 class GetPolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the policy store associated with the alias.
2480 2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2480 class GetPolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the policy store alias. Policy Store Aliases in the Active state can be used normally. When a policy store alias is deleted, it enters the PendingDeletion state. Policy Store Aliases in the PendingDeletion cannot be used, and creating a policy store alias with the same alias name will fail.
2480 2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2480 class GetPolicyStoreAliasOutput < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |