Class: Aws::VerifiedPermissions::Types::GetPolicyStoreOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the policy store.

Returns:

  • (String)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#cedar_versionString

The version of the Cedar language used with policies, policy templates, and schemas in this policy store. For more information, see Amazon Verified Permissions upgrade to Cedar v4 FAQ.

Returns:

  • (String)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_dateTime

The date and time that the policy store was originally created.

Returns:

  • (Time)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#deletion_protectionString

Specifies whether the policy store can be deleted. If enabled, the policy store can't be deleted.

The default state is DISABLED.

Returns:

  • (String)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

Descriptive text that you can provide to help with identification of the current policy store.

Returns:

  • (String)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#encryption_stateTypes::EncryptionState

A structure that contains the encryption configuration for the policy store.



2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_dateTime

The date and time that the policy store was last updated.

Returns:

  • (Time)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#policy_store_idString

The ID of the policy store;

Returns:

  • (String)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The list of tags associated with the policy store.

Returns:

  • (Hash<String,String>)


2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#validation_settingsTypes::ValidationSettings

The current validation settings for the policy store.



2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581

class GetPolicyStoreOutput < Struct.new(
  :policy_store_id,
  :arn,
  :validation_settings,
  :created_date,
  :last_updated_date,
  :description,
  :deletion_protection,
  :encryption_state,
  :cedar_version,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end