Class: Aws::VerifiedPermissions::Types::GetSchemaInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::GetSchemaInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the schema.
Instance Attribute Details
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the schema.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2686 class GetSchemaInput < Struct.new( :policy_store_id) SENSITIVE = [] include Aws::Structure end |