Class: Aws::VerifiedPermissions::Types::IdentitySourceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::IdentitySourceDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
A structure that contains configuration of the identity source.
This data type was a response parameter for the [GetIdentitySource] operation. Replaced by [ConfigurationDetail].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_GetIdentitySource.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ConfigurationDetail.html
Constant Summary collapse
- SENSITIVE =
[:client_ids]
Instance Attribute Summary collapse
-
#client_ids ⇒ Array<String>
The application client IDs associated with the specified Amazon Cognito user pool that are enabled for this identity source.
-
#discovery_url ⇒ String
The well-known URL that points to this user pool’s OIDC discovery endpoint.
-
#open_id_issuer ⇒ String
A string that identifies the type of OIDC service represented by this identity source.
-
#user_pool_arn ⇒ String
The [Amazon Resource Name (ARN)] of the Amazon Cognito user pool whose identities are accessible to this Verified Permissions policy store.
Instance Attribute Details
#client_ids ⇒ Array<String>
The application client IDs associated with the specified Amazon Cognito user pool that are enabled for this identity source.
2781 2782 2783 2784 2785 2786 2787 2788 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2781 class IdentitySourceDetails < Struct.new( :client_ids, :user_pool_arn, :discovery_url, :open_id_issuer) SENSITIVE = [:client_ids] include Aws::Structure end |
#discovery_url ⇒ String
The well-known URL that points to this user pool’s OIDC discovery endpoint. This is a URL string in the following format. This URL replaces the placeholders for both the Amazon Web Services Region and the user pool identifier with those appropriate for this user pool.
‘cognito-idp.<region>.amazonaws.com/<user-pool-id>/.well-known/openid-configuration`
2781 2782 2783 2784 2785 2786 2787 2788 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2781 class IdentitySourceDetails < Struct.new( :client_ids, :user_pool_arn, :discovery_url, :open_id_issuer) SENSITIVE = [:client_ids] include Aws::Structure end |
#open_id_issuer ⇒ String
A string that identifies the type of OIDC service represented by this identity source.
At this time, the only valid value is ‘cognito`.
2781 2782 2783 2784 2785 2786 2787 2788 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2781 class IdentitySourceDetails < Struct.new( :client_ids, :user_pool_arn, :discovery_url, :open_id_issuer) SENSITIVE = [:client_ids] include Aws::Structure end |
#user_pool_arn ⇒ String
The [Amazon Resource Name (ARN)] of the Amazon Cognito user pool whose identities are accessible to this Verified Permissions policy store.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2781 2782 2783 2784 2785 2786 2787 2788 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2781 class IdentitySourceDetails < Struct.new( :client_ids, :user_pool_arn, :discovery_url, :open_id_issuer) SENSITIVE = [:client_ids] include Aws::Structure end |