Class: Aws::VerifiedPermissions::Types::IsAuthorizedInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionTypes::ActionIdentifier

Specifies the requested action to be authorized. For example, is the principal authorized to perform this action on the resource?



2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2998

class IsAuthorizedInput < Struct.new(
  :policy_store_id,
  :principal,
  :action,
  :resource,
  :context,
  :entities)
  SENSITIVE = []
  include Aws::Structure
end

#contextTypes::ContextDefinition

Specifies additional context that can be used to make more granular authorization decisions.



2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2998

class IsAuthorizedInput < Struct.new(
  :policy_store_id,
  :principal,
  :action,
  :resource,
  :context,
  :entities)
  SENSITIVE = []
  include Aws::Structure
end

#entitiesTypes::EntitiesDefinition

(Optional) Specifies the list of resources and principals and their associated attributes that Verified Permissions can examine when evaluating the policies. These additional entities and their attributes can be referenced and checked by conditional elements in the policies in the specified policy store.

<note markdown=“1”> You can include only principal and resource entities in this parameter; you can’t include actions. You must specify actions in the schema.

</note>


2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2998

class IsAuthorizedInput < Struct.new(
  :policy_store_id,
  :principal,
  :action,
  :resource,
  :context,
  :entities)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store. Policies in this policy store will be used to make an authorization decision for the input.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2998

class IsAuthorizedInput < Struct.new(
  :policy_store_id,
  :principal,
  :action,
  :resource,
  :context,
  :entities)
  SENSITIVE = []
  include Aws::Structure
end

#principalTypes::EntityIdentifier

Specifies the principal for which the authorization decision is to be made.



2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2998

class IsAuthorizedInput < Struct.new(
  :policy_store_id,
  :principal,
  :action,
  :resource,
  :context,
  :entities)
  SENSITIVE = []
  include Aws::Structure
end

#resourceTypes::EntityIdentifier

Specifies the resource for which the authorization decision is to be made.



2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2998

class IsAuthorizedInput < Struct.new(
  :policy_store_id,
  :principal,
  :action,
  :resource,
  :context,
  :entities)
  SENSITIVE = []
  include Aws::Structure
end