Class: Aws::VerifiedPermissions::Types::IsAuthorizedWithTokenOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::IsAuthorizedWithTokenOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:errors]
Instance Attribute Summary collapse
-
#decision ⇒ String
An authorization decision that indicates if the authorization request should be allowed or denied.
-
#determining_policies ⇒ Array<Types::DeterminingPolicyItem>
The list of determining policies used to make the authorization decision.
-
#errors ⇒ Array<Types::EvaluationErrorItem>
Errors that occurred while making an authorization decision.
-
#principal ⇒ Types::EntityIdentifier
The identifier of the principal in the ID or access token.
Instance Attribute Details
#decision ⇒ String
An authorization decision that indicates if the authorization request should be allowed or denied.
3156 3157 3158 3159 3160 3161 3162 3163 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3156 class IsAuthorizedWithTokenOutput < Struct.new( :decision, :determining_policies, :errors, :principal) SENSITIVE = [:errors] include Aws::Structure end |
#determining_policies ⇒ Array<Types::DeterminingPolicyItem>
The list of determining policies used to make the authorization decision. For example, if there are multiple matching policies, where at least one is a forbid policy, then because forbid always overrides permit the forbid policies are the determining policies. If all matching policies are permit policies, then those policies are the determining policies. When no policies match and the response is the default DENY, there are no determining policies.
3156 3157 3158 3159 3160 3161 3162 3163 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3156 class IsAuthorizedWithTokenOutput < Struct.new( :decision, :determining_policies, :errors, :principal) SENSITIVE = [:errors] include Aws::Structure end |
#errors ⇒ Array<Types::EvaluationErrorItem>
Errors that occurred while making an authorization decision. For example, a policy references an entity or entity attribute that does not exist in the slice.
3156 3157 3158 3159 3160 3161 3162 3163 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3156 class IsAuthorizedWithTokenOutput < Struct.new( :decision, :determining_policies, :errors, :principal) SENSITIVE = [:errors] include Aws::Structure end |
#principal ⇒ Types::EntityIdentifier
The identifier of the principal in the ID or access token.
3156 3157 3158 3159 3160 3161 3162 3163 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3156 class IsAuthorizedWithTokenOutput < Struct.new( :decision, :determining_policies, :errors, :principal) SENSITIVE = [:errors] include Aws::Structure end |