Class: Aws::VerifiedPermissions::Types::KmsEncryptionState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

A structure that contains the KMS encryption configuration for the policy store. The encryption state shows what customer-managed KMS key is being used to encrypt all resources within the policy store, and any user-defined context key-value pairs added during encryption processes.

This data type is used as a field that is part of the

EncryptionState][1

type.

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_EncryptionState.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_contextHash<String,String>

User-defined, additional context added to encryption processes.

Returns:

  • (Hash<String,String>)


3220
3221
3222
3223
3224
3225
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3220

class KmsEncryptionState < Struct.new(
  :key,
  :encryption_context)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The customer-managed KMS key [Amazon Resource Name (ARN)] being used for encryption processes.

[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html

Returns:

  • (String)


3220
3221
3222
3223
3224
3225
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3220

class KmsEncryptionState < Struct.new(
  :key,
  :encryption_context)
  SENSITIVE = []
  include Aws::Structure
end