Class: Aws::VerifiedPermissions::Types::ListIdentitySourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::ListIdentitySourcesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::IdentitySourceFilter>
Specifies characteristics of an identity source that you can use to limit the output to matching identity sources.
-
#max_results ⇒ Integer
Specifies the total number of results that you want included in each response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the identity sources that you want to list.
Instance Attribute Details
#filters ⇒ Array<Types::IdentitySourceFilter>
Specifies characteristics of an identity source that you can use to limit the output to matching identity sources.
3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3289 class ListIdentitySourcesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specifies the total number of results that you want included in each
response. If additional items exist beyond the number you specify,
the NextToken response element is returned with a value (not
null). Include the specified value as the NextToken request
parameter in the next call to the operation to get the next set of
results. Note that the service might return fewer results than the
maximum even when there are more results available. You should check
NextToken after every operation to ensure that you receive all of
the results.
If you do not specify this parameter, the operation defaults to 10 identity sources per response. You can specify a maximum of 50 identity sources per response.
3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3289 class ListIdentitySourcesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid
only if you received a NextToken response in the previous request.
If you did, it indicates that more output is available. Set this
parameter to the value provided by the previous call's NextToken
response to request the next page of results.
3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3289 class ListIdentitySourcesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the identity sources that you want to list.
To specify a policy store, use its ID or alias name. When using an
alias name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.
3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3289 class ListIdentitySourcesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |