Class: Aws::VerifiedPermissions::Types::ListPoliciesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::ListPoliciesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::PolicyFilter
Specifies a filter that limits the response to only policies that match the specified criteria.
-
#max_results ⇒ Integer
Specifies the total number of results that you want included in each response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store you want to list policies from.
Instance Attribute Details
#filter ⇒ Types::PolicyFilter
Specifies a filter that limits the response to only policies that match the specified criteria. For example, you list only the policies that reference a specified principal.
3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3369 class ListPoliciesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specifies the total number of results that you want included in each
response. If additional items exist beyond the number you specify,
the NextToken response element is returned with a value (not
null). Include the specified value as the NextToken request
parameter in the next call to the operation to get the next set of
results. Note that the service might return fewer results than the
maximum even when there are more results available. You should check
NextToken after every operation to ensure that you receive all of
the results.
If you do not specify this parameter, the operation defaults to 10 policies per response. You can specify a maximum of 50 policies per response.
3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3369 class ListPoliciesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid
only if you received a NextToken response in the previous request.
If you did, it indicates that more output is available. Set this
parameter to the value provided by the previous call's NextToken
response to request the next page of results.
3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3369 class ListPoliciesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store you want to list policies from.
To specify a policy store, use its ID or alias name. When using an
alias name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.
3369 3370 3371 3372 3373 3374 3375 3376 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3369 class ListPoliciesInput < Struct.new( :policy_store_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |