Class: Aws::VerifiedPermissions::Types::ListPolicyTemplatesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::ListPolicyTemplatesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the total number of results that you want included in each response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy templates you want to list.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the total number of results that you want included in each
response. If additional items exist beyond the number you specify,
the NextToken response element is returned with a value (not
null). Include the specified value as the NextToken request
parameter in the next call to the operation to get the next set of
results. Note that the service might return fewer results than the
maximum even when there are more results available. You should check
NextToken after every operation to ensure that you receive all of
the results.
If you do not specify this parameter, the operation defaults to 10 policy templates per response. You can specify a maximum of 50 policy templates per response.
3561 3562 3563 3564 3565 3566 3567 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3561 class ListPolicyTemplatesInput < Struct.new( :policy_store_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid
only if you received a NextToken response in the previous request.
If you did, it indicates that more output is available. Set this
parameter to the value provided by the previous call's NextToken
response to request the next page of results.
3561 3562 3563 3564 3565 3566 3567 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3561 class ListPolicyTemplatesInput < Struct.new( :policy_store_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy templates you want to list.
To specify a policy store, use its ID or alias name. When using an
alias name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.
3561 3562 3563 3564 3565 3566 3567 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3561 class ListPolicyTemplatesInput < Struct.new( :policy_store_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |