Class: Aws::VerifiedPermissions::Types::OpenIdConnectTokenSelectionDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::OpenIdConnectTokenSelectionDetail
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
OpenIdConnectTokenSelectionDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OpenIdConnectTokenSelectionDetail corresponding to the set member.
The token type that you want to process from your OIDC identity provider. Your policy store can process either identity (ID) or access tokens from a given OIDC identity source.
This data type is part of a [OpenIdConnectConfigurationDetail] structure, which is a parameter of [GetIdentitySource].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_OpenIdConnectConfigurationDetail.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_GetIdentitySource.html
Direct Known Subclasses
Defined Under Namespace
Classes: AccessTokenOnly, IdentityTokenOnly, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_token_only ⇒ Types::OpenIdConnectAccessTokenConfigurationDetail
The OIDC configuration for processing access tokens.
-
#identity_token_only ⇒ Types::OpenIdConnectIdentityTokenConfigurationDetail
The OIDC configuration for processing identity (ID) tokens.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_token_only ⇒ Types::OpenIdConnectAccessTokenConfigurationDetail
The OIDC configuration for processing access tokens. Contains allowed audience claims, for example ‘auth.example.com`, and the claim that you want to map to the principal, for example `sub`.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4137 class OpenIdConnectTokenSelectionDetail < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < OpenIdConnectTokenSelectionDetail; end class IdentityTokenOnly < OpenIdConnectTokenSelectionDetail; end class Unknown < OpenIdConnectTokenSelectionDetail; end end |
#identity_token_only ⇒ Types::OpenIdConnectIdentityTokenConfigurationDetail
The OIDC configuration for processing identity (ID) tokens. Contains allowed client ID claims, for example ‘1example23456789`, and the claim that you want to map to the principal, for example `sub`.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4137 class OpenIdConnectTokenSelectionDetail < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < OpenIdConnectTokenSelectionDetail; end class IdentityTokenOnly < OpenIdConnectTokenSelectionDetail; end class Unknown < OpenIdConnectTokenSelectionDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4137 4138 4139 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4137 def unknown @unknown end |