Class: Aws::VerifiedPermissions::Types::OpenIdConnectTokenSelectionItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::OpenIdConnectTokenSelectionItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
OpenIdConnectTokenSelectionItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OpenIdConnectTokenSelectionItem corresponding to the set member.
The token type that you want to process from your OIDC identity provider. Your policy store can process either identity (ID) or access tokens from a given OIDC identity source.
This data type is part of a [OpenIdConnectConfigurationItem] structure, which is a parameter of [ListIdentitySources].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_OpenIdConnectConfigurationItem.html [2]: amazonaws.com/verifiedpermissions/latest/apireference/API_ListIdentitySources.html
Direct Known Subclasses
Defined Under Namespace
Classes: AccessTokenOnly, IdentityTokenOnly, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_token_only ⇒ Types::OpenIdConnectAccessTokenConfigurationItem
The OIDC configuration for processing access tokens.
-
#identity_token_only ⇒ Types::OpenIdConnectIdentityTokenConfigurationItem
The OIDC configuration for processing identity (ID) tokens.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_token_only ⇒ Types::OpenIdConnectAccessTokenConfigurationItem
The OIDC configuration for processing access tokens. Contains allowed audience claims, for example ‘auth.example.com`, and the claim that you want to map to the principal, for example `sub`.
4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4165 class OpenIdConnectTokenSelectionItem < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < OpenIdConnectTokenSelectionItem; end class IdentityTokenOnly < OpenIdConnectTokenSelectionItem; end class Unknown < OpenIdConnectTokenSelectionItem; end end |
#identity_token_only ⇒ Types::OpenIdConnectIdentityTokenConfigurationItem
The OIDC configuration for processing identity (ID) tokens. Contains allowed client ID claims, for example ‘1example23456789`, and the claim that you want to map to the principal, for example `sub`.
4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4165 class OpenIdConnectTokenSelectionItem < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < OpenIdConnectTokenSelectionItem; end class IdentityTokenOnly < OpenIdConnectTokenSelectionItem; end class Unknown < OpenIdConnectTokenSelectionItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4165 4166 4167 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4165 def unknown @unknown end |