Class: Aws::VerifiedPermissions::Types::PolicyItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::PolicyItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Contains information about a policy.
This data type is used as a response parameter for the
- ListPolicies][1
-
operation.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicies.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::ActionIdentifier>
The action that a policy permits or forbids.
-
#created_date ⇒ Time
The date and time the policy was created.
-
#definition ⇒ Types::PolicyDefinitionItem
The policy definition of an item in the list of policies returned.
-
#effect ⇒ String
The effect of the decision that a policy returns to an authorization request.
-
#last_updated_date ⇒ Time
The date and time the policy was most recently updated.
-
#name ⇒ String
The name of the policy, if one was assigned when the policy was created or last updated.
-
#policy_id ⇒ String
The identifier of the policy you want information about.
-
#policy_store_id ⇒ String
The identifier of the policy store where the policy you want information about is stored.
-
#policy_type ⇒ String
The type of the policy.
-
#principal ⇒ Types::EntityIdentifier
The principal associated with the policy.
-
#resource ⇒ Types::EntityIdentifier
The resource associated with the policy.
Instance Attribute Details
#actions ⇒ Array<Types::ActionIdentifier>
The action that a policy permits or forbids. For example, ‘[{“actionId”: “ViewPhoto”, “actionType”: “PhotoFlash::Action”, “SharePhoto”, “entityType”: “PhotoFlash::Action”]}`.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date and time the policy was created.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ Types::PolicyDefinitionItem
The policy definition of an item in the list of policies returned.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#effect ⇒ String
The effect of the decision that a policy returns to an authorization request. For example, ‘“effect”: “Permit”`.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#last_updated_date ⇒ Time
The date and time the policy was most recently updated.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the policy, if one was assigned when the policy was created or last updated.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#policy_id ⇒ String
The identifier of the policy you want information about.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
The identifier of the policy store where the policy you want information about is stored.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#policy_type ⇒ String
The type of the policy. This is one of the following values:
-
‘STATIC`
-
‘TEMPLATE_LINKED`
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ Types::EntityIdentifier
The principal associated with the policy.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::EntityIdentifier
The resource associated with the policy.
4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4418 class PolicyItem < Struct.new( :policy_store_id, :policy_id, :policy_type, :principal, :resource, :actions, :definition, :created_date, :last_updated_date, :effect, :name) SENSITIVE = [] include Aws::Structure end |