Class: Aws::VerifiedPermissions::Types::PolicyStoreAliasItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Contains information about a policy store alias.

This data type is used as a response parameter for the

ListPolicyStoreAliases][1

operation.

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_arnString

The Amazon Resource Name (ARN) of the policy store alias.

Returns:

  • (String)


4471
4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471

class PolicyStoreAliasItem < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#alias_nameString

The name of the policy store alias.

Returns:

  • (String)


4471
4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471

class PolicyStoreAliasItem < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the policy store alias was created.

Returns:

  • (Time)


4471
4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471

class PolicyStoreAliasItem < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

The ID of the policy store associated with the alias.

Returns:

  • (String)


4471
4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471

class PolicyStoreAliasItem < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the policy store alias. Policy Store Aliases in the Active state can be used normally. When a policy store alias is deleted, it enters the PendingDeletion state. Policy Store Aliases in the PendingDeletion state cannot be used, and creating a policy store alias with the same alias name will fail.

Returns:

  • (String)


4471
4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471

class PolicyStoreAliasItem < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end