Class: Aws::VerifiedPermissions::Types::PolicyStoreItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Contains information about a policy store.

This data type is used as a response parameter for the

ListPolicyStores][1

operation.

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStores.html

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the policy store.

Returns:

  • (String)


4526
4527
4528
4529
4530
4531
4532
4533
4534
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4526

class PolicyStoreItem < Struct.new(
  :policy_store_id,
  :arn,
  :created_date,
  :last_updated_date,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_dateTime

The date and time the policy was created.

Returns:

  • (Time)


4526
4527
4528
4529
4530
4531
4532
4533
4534
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4526

class PolicyStoreItem < Struct.new(
  :policy_store_id,
  :arn,
  :created_date,
  :last_updated_date,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

Descriptive text that you can provide to help with identification of the current policy store.

Returns:

  • (String)


4526
4527
4528
4529
4530
4531
4532
4533
4534
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4526

class PolicyStoreItem < Struct.new(
  :policy_store_id,
  :arn,
  :created_date,
  :last_updated_date,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#last_updated_dateTime

The date and time the policy store was most recently updated.

Returns:

  • (Time)


4526
4527
4528
4529
4530
4531
4532
4533
4534
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4526

class PolicyStoreItem < Struct.new(
  :policy_store_id,
  :arn,
  :created_date,
  :last_updated_date,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#policy_store_idString

The unique identifier of the policy store.

Returns:

  • (String)


4526
4527
4528
4529
4530
4531
4532
4533
4534
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4526

class PolicyStoreItem < Struct.new(
  :policy_store_id,
  :arn,
  :created_date,
  :last_updated_date,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end