Class: Aws::VerifiedPermissions::Types::PolicyTemplateItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::PolicyTemplateItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Contains details about a policy template
This data type is used as a response parameter for the
- ListPolicyTemplates][1
-
operation.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyTemplates.html
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_date ⇒ Time
The date and time that the policy template was created.
-
#description ⇒ String
The description attached to the policy template.
-
#last_updated_date ⇒ Time
The date and time that the policy template was most recently updated.
-
#name ⇒ String
The name of the policy template, if one was assigned when the policy template was created or last updated.
-
#policy_store_id ⇒ String
The unique identifier of the policy store that contains the template.
-
#policy_template_id ⇒ String
The unique identifier of the policy template.
Instance Attribute Details
#created_date ⇒ Time
The date and time that the policy template was created.
4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4561 class PolicyTemplateItem < Struct.new( :policy_store_id, :policy_template_id, :description, :created_date, :last_updated_date, :name) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description attached to the policy template.
4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4561 class PolicyTemplateItem < Struct.new( :policy_store_id, :policy_template_id, :description, :created_date, :last_updated_date, :name) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_date ⇒ Time
The date and time that the policy template was most recently updated.
4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4561 class PolicyTemplateItem < Struct.new( :policy_store_id, :policy_template_id, :description, :created_date, :last_updated_date, :name) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the policy template, if one was assigned when the policy template was created or last updated.
4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4561 class PolicyTemplateItem < Struct.new( :policy_store_id, :policy_template_id, :description, :created_date, :last_updated_date, :name) SENSITIVE = [:description] include Aws::Structure end |
#policy_store_id ⇒ String
The unique identifier of the policy store that contains the template.
4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4561 class PolicyTemplateItem < Struct.new( :policy_store_id, :policy_template_id, :description, :created_date, :last_updated_date, :name) SENSITIVE = [:description] include Aws::Structure end |
#policy_template_id ⇒ String
The unique identifier of the policy template.
4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4561 class PolicyTemplateItem < Struct.new( :policy_store_id, :policy_template_id, :description, :created_date, :last_updated_date, :name) SENSITIVE = [:description] include Aws::Structure end |