Class: Aws::VerifiedPermissions::Types::PutSchemaInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#definitionTypes::SchemaDefinition

Specifies the definition of the schema to be stored. The schema definition must be written in Cedar schema JSON.



4596
4597
4598
4599
4600
4601
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4596

class PutSchemaInput < Struct.new(
  :policy_store_id,
  :definition)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store in which to place the schema.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


4596
4597
4598
4599
4600
4601
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4596

class PutSchemaInput < Struct.new(
  :policy_store_id,
  :definition)
  SENSITIVE = []
  include Aws::Structure
end