Class: Aws::VerifiedPermissions::Types::ResourceConflict
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::ResourceConflict
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Contains information about a resource conflict.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_id ⇒ String
The unique identifier of the resource involved in a conflict.
-
#resource_type ⇒ String
The type of the resource involved in a conflict.
Instance Attribute Details
#resource_id ⇒ String
The unique identifier of the resource involved in a conflict.
4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4655 class ResourceConflict < Struct.new( :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource involved in a conflict.
4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4655 class ResourceConflict < Struct.new( :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |