Class: Aws::VerifiedPermissions::Types::SchemaDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::SchemaDefinition
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
SchemaDefinition is a union - when making an API calls you must set exactly one of the members.
Contains a list of principal types, resource types, and actions that can be specified in policies stored in the same policy store. If the validation mode for the policy store is set to ‘STRICT`, then policies that can’t be validated by this schema are rejected by Verified Permissions and can’t be stored in the policy store.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[:cedar_json]
Instance Attribute Summary collapse
-
#cedar_json ⇒ String
A JSON string representation of the schema supported by applications that use this policy store.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#cedar_json ⇒ String
A JSON string representation of the schema supported by applications that use this policy store. To delete the schema, run [PutSchema] with ‘{}` for this parameter. For more information, see [Policy store schema] in the *Amazon Verified Permissions User Guide*.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_PutSchema.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/userguide/schema.html
4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4695 class SchemaDefinition < Struct.new( :cedar_json, :unknown) SENSITIVE = [:cedar_json] include Aws::Structure include Aws::Structure::Union class CedarJson < SchemaDefinition; end class Unknown < SchemaDefinition; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4695 4696 4697 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4695 def unknown @unknown end |