Class: Aws::VerifiedPermissions::Types::UpdateIdentitySourceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:principal_entity_type]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_source_idString

Specifies the ID of the identity source that you want to update.

Returns:

  • (String)


5121
5122
5123
5124
5125
5126
5127
5128
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121

class UpdateIdentitySourceInput < Struct.new(
  :policy_store_id,
  :identity_source_id,
  :update_configuration,
  :principal_entity_type)
  SENSITIVE = [:principal_entity_type]
  include Aws::Structure
end

#policy_store_idString

Specifies the ID of the policy store that contains the identity source that you want to update.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


5121
5122
5123
5124
5125
5126
5127
5128
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121

class UpdateIdentitySourceInput < Struct.new(
  :policy_store_id,
  :identity_source_id,
  :update_configuration,
  :principal_entity_type)
  SENSITIVE = [:principal_entity_type]
  include Aws::Structure
end

#principal_entity_typeString

Specifies the data type of principals generated for identities authenticated by the identity source.

Returns:

  • (String)


5121
5122
5123
5124
5125
5126
5127
5128
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121

class UpdateIdentitySourceInput < Struct.new(
  :policy_store_id,
  :identity_source_id,
  :update_configuration,
  :principal_entity_type)
  SENSITIVE = [:principal_entity_type]
  include Aws::Structure
end

#update_configurationTypes::UpdateConfiguration

Specifies the details required to communicate with the identity provider (IdP) associated with this identity source.



5121
5122
5123
5124
5125
5126
5127
5128
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121

class UpdateIdentitySourceInput < Struct.new(
  :policy_store_id,
  :identity_source_id,
  :update_configuration,
  :principal_entity_type)
  SENSITIVE = [:principal_entity_type]
  include Aws::Structure
end