Class: Aws::VerifiedPermissions::Types::UpdateOpenIdConnectTokenSelection
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::UpdateOpenIdConnectTokenSelection
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
UpdateOpenIdConnectTokenSelection is a union - when making an API calls you must set exactly one of the members.
The token type that you want to process from your OIDC identity provider. Your policy store can process either identity (ID) or access tokens from a given OIDC identity source.
This data type is part of a [UpdateOpenIdConnectConfiguration] structure, which is a parameter to [UpdateIdentitySource].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdateOpenIdConnectConfiguration.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_UpdateIdentitySource.html
Direct Known Subclasses
Defined Under Namespace
Classes: AccessTokenOnly, IdentityTokenOnly, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_token_only ⇒ Types::UpdateOpenIdConnectAccessTokenConfiguration
The OIDC configuration for processing access tokens.
-
#identity_token_only ⇒ Types::UpdateOpenIdConnectIdentityTokenConfiguration
The OIDC configuration for processing identity (ID) tokens.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_token_only ⇒ Types::UpdateOpenIdConnectAccessTokenConfiguration
The OIDC configuration for processing access tokens. Contains allowed audience claims, for example ‘auth.example.com`, and the claim that you want to map to the principal, for example `sub`.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5352 class UpdateOpenIdConnectTokenSelection < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < UpdateOpenIdConnectTokenSelection; end class IdentityTokenOnly < UpdateOpenIdConnectTokenSelection; end class Unknown < UpdateOpenIdConnectTokenSelection; end end |
#identity_token_only ⇒ Types::UpdateOpenIdConnectIdentityTokenConfiguration
The OIDC configuration for processing identity (ID) tokens. Contains allowed client ID claims, for example ‘1example23456789`, and the claim that you want to map to the principal, for example `sub`.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5352 class UpdateOpenIdConnectTokenSelection < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < UpdateOpenIdConnectTokenSelection; end class IdentityTokenOnly < UpdateOpenIdConnectTokenSelection; end class Unknown < UpdateOpenIdConnectTokenSelection; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5352 5353 5354 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5352 def unknown @unknown end |