Class: Aws::VerifiedPermissions::Types::UpdatePolicyStoreOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::UpdatePolicyStoreOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The [Amazon Resource Name (ARN)] of the updated policy store.
-
#created_date ⇒ Time
The date and time that the policy store was originally created.
-
#last_updated_date ⇒ Time
The date and time that the policy store was most recently updated.
-
#policy_store_id ⇒ String
The ID of the updated policy store.
Instance Attribute Details
#arn ⇒ String
The [Amazon Resource Name (ARN)] of the updated policy store.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
5596 5597 5598 5599 5600 5601 5602 5603 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5596 class UpdatePolicyStoreOutput < Struct.new( :policy_store_id, :arn, :created_date, :last_updated_date) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date and time that the policy store was originally created.
5596 5597 5598 5599 5600 5601 5602 5603 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5596 class UpdatePolicyStoreOutput < Struct.new( :policy_store_id, :arn, :created_date, :last_updated_date) SENSITIVE = [] include Aws::Structure end |
#last_updated_date ⇒ Time
The date and time that the policy store was most recently updated.
5596 5597 5598 5599 5600 5601 5602 5603 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5596 class UpdatePolicyStoreOutput < Struct.new( :policy_store_id, :arn, :created_date, :last_updated_date) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the updated policy store.
5596 5597 5598 5599 5600 5601 5602 5603 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5596 class UpdatePolicyStoreOutput < Struct.new( :policy_store_id, :arn, :created_date, :last_updated_date) SENSITIVE = [] include Aws::Structure end |