Module: Aws::VerifiedPermissions::Types
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Defined Under Namespace
Classes: AccessDeniedException, ActionIdentifier, AttributeValue, BatchGetPolicyErrorItem, BatchGetPolicyInput, BatchGetPolicyInputItem, BatchGetPolicyOutput, BatchGetPolicyOutputItem, BatchIsAuthorizedInput, BatchIsAuthorizedInputItem, BatchIsAuthorizedOutput, BatchIsAuthorizedOutputItem, BatchIsAuthorizedWithTokenInput, BatchIsAuthorizedWithTokenInputItem, BatchIsAuthorizedWithTokenOutput, BatchIsAuthorizedWithTokenOutputItem, CedarTagValue, CognitoGroupConfiguration, CognitoGroupConfigurationDetail, CognitoGroupConfigurationItem, CognitoUserPoolConfiguration, CognitoUserPoolConfigurationDetail, CognitoUserPoolConfigurationItem, Configuration, ConfigurationDetail, ConfigurationItem, ConflictException, ContextDefinition, CreateIdentitySourceInput, CreateIdentitySourceOutput, CreatePolicyInput, CreatePolicyOutput, CreatePolicyStoreAliasInput, CreatePolicyStoreAliasOutput, CreatePolicyStoreInput, CreatePolicyStoreOutput, CreatePolicyTemplateInput, CreatePolicyTemplateOutput, DeleteIdentitySourceInput, DeleteIdentitySourceOutput, DeletePolicyInput, DeletePolicyOutput, DeletePolicyStoreAliasInput, DeletePolicyStoreAliasOutput, DeletePolicyStoreInput, DeletePolicyStoreOutput, DeletePolicyTemplateInput, DeletePolicyTemplateOutput, DeterminingPolicyItem, EncryptionSettings, EncryptionState, EntitiesDefinition, EntityIdentifier, EntityItem, EntityReference, EvaluationErrorItem, GetIdentitySourceInput, GetIdentitySourceOutput, GetPolicyInput, GetPolicyOutput, GetPolicyStoreAliasInput, GetPolicyStoreAliasOutput, GetPolicyStoreInput, GetPolicyStoreOutput, GetPolicyTemplateInput, GetPolicyTemplateOutput, GetSchemaInput, GetSchemaOutput, IdentitySourceDetails, IdentitySourceFilter, IdentitySourceItem, IdentitySourceItemDetails, InternalServerException, InvalidStateException, IsAuthorizedInput, IsAuthorizedOutput, IsAuthorizedWithTokenInput, IsAuthorizedWithTokenOutput, KmsEncryptionSettings, KmsEncryptionState, ListIdentitySourcesInput, ListIdentitySourcesOutput, ListPoliciesInput, ListPoliciesOutput, ListPolicyStoreAliasesInput, ListPolicyStoreAliasesOutput, ListPolicyStoresInput, ListPolicyStoresOutput, ListPolicyTemplatesInput, ListPolicyTemplatesOutput, ListTagsForResourceInput, ListTagsForResourceOutput, OpenIdConnectAccessTokenConfiguration, OpenIdConnectAccessTokenConfigurationDetail, OpenIdConnectAccessTokenConfigurationItem, OpenIdConnectConfiguration, OpenIdConnectConfigurationDetail, OpenIdConnectConfigurationItem, OpenIdConnectGroupConfiguration, OpenIdConnectGroupConfigurationDetail, OpenIdConnectGroupConfigurationItem, OpenIdConnectIdentityTokenConfiguration, OpenIdConnectIdentityTokenConfigurationDetail, OpenIdConnectIdentityTokenConfigurationItem, OpenIdConnectTokenSelection, OpenIdConnectTokenSelectionDetail, OpenIdConnectTokenSelectionItem, PolicyDefinition, PolicyDefinitionDetail, PolicyDefinitionItem, PolicyFilter, PolicyItem, PolicyStoreAliasFilter, PolicyStoreAliasItem, PolicyStoreItem, PolicyTemplateItem, PutSchemaInput, PutSchemaOutput, ResourceConflict, ResourceNotFoundException, SchemaDefinition, ServiceQuotaExceededException, StaticPolicyDefinition, StaticPolicyDefinitionDetail, StaticPolicyDefinitionItem, TagResourceInput, TagResourceOutput, TemplateLinkedPolicyDefinition, TemplateLinkedPolicyDefinitionDetail, TemplateLinkedPolicyDefinitionItem, ThrottlingException, TooManyTagsException, Unit, UntagResourceInput, UntagResourceOutput, UpdateCognitoGroupConfiguration, UpdateCognitoUserPoolConfiguration, UpdateConfiguration, UpdateIdentitySourceInput, UpdateIdentitySourceOutput, UpdateOpenIdConnectAccessTokenConfiguration, UpdateOpenIdConnectConfiguration, UpdateOpenIdConnectGroupConfiguration, UpdateOpenIdConnectIdentityTokenConfiguration, UpdateOpenIdConnectTokenSelection, UpdatePolicyDefinition, UpdatePolicyInput, UpdatePolicyOutput, UpdatePolicyStoreInput, UpdatePolicyStoreOutput, UpdatePolicyTemplateInput, UpdatePolicyTemplateOutput, UpdateStaticPolicyDefinition, ValidationException, ValidationExceptionField, ValidationSettings
Instance Attribute Summary collapse
-
#access_token_only ⇒ Types::UpdateOpenIdConnectAccessTokenConfiguration
The OIDC configuration for processing access tokens.
-
#boolean ⇒ Boolean
A Cedar tag value of [Boolean] type.
-
#cedar_json ⇒ String
A JSON string representation of the schema supported by applications that use this policy store.
-
#cognito_user_pool_configuration ⇒ Types::UpdateCognitoUserPoolConfiguration
Contains configuration details of a Amazon Cognito user pool.
-
#context_map ⇒ Hash<String,Types::AttributeValue>
An list of attributes that are needed to successfully evaluate an authorization request.
-
#datetime ⇒ String
A Cedar tag value of [datetime] type.
-
#decimal ⇒ String
A Cedar tag value of [decimal] type.
-
#default ⇒ Types::Unit
This is the default encryption state.
-
#duration ⇒ String
A Cedar tag value of [duration] type.
-
#entity_identifier ⇒ Types::EntityIdentifier
A Cedar tag value of type [EntityIdentifier].
-
#entity_list ⇒ Array<Types::EntityItem>
An array of entities that are needed to successfully evaluate an authorization request.
-
#identifier ⇒ Types::EntityIdentifier
The identifier of the entity.
-
#identity_token_only ⇒ Types::UpdateOpenIdConnectIdentityTokenConfiguration
The OIDC configuration for processing identity (ID) tokens.
-
#ipaddr ⇒ String
A Cedar tag value of [ipaddr] type.
-
#kms_encryption_settings ⇒ Types::KmsEncryptionSettings
The KMS encryption settings for this policy store to encrypt data with.
-
#kms_encryption_state ⇒ Types::KmsEncryptionState
The KMS encryption settings currently configured for this policy store to encrypt data with.
-
#long ⇒ Integer
A Cedar tag value of [Long] type.
-
#open_id_connect_configuration ⇒ Types::UpdateOpenIdConnectConfiguration
Contains configuration details of an OpenID Connect (OIDC) identity provider, or identity source, that Verified Permissions can use to generate entities from authenticated identities.
-
#record ⇒ Hash<String,Types::CedarTagValue>
A Cedar tag value of [Record] type.
-
#set ⇒ Array<Types::CedarTagValue>
A Cedar tag value of [Set] type.
-
#static ⇒ Types::UpdateStaticPolicyDefinition
Contains details about the updates to be applied to a static policy.
-
#string ⇒ String
A Cedar tag value of [String] type.
-
#template_linked ⇒ Types::TemplateLinkedPolicyDefinitionItem
Information about a template-linked policy that was created by instantiating a policy template.
-
#unspecified ⇒ Boolean
Used to indicate that a principal or resource is not specified.
Instance Attribute Details
#access_token_only ⇒ Types::UpdateOpenIdConnectAccessTokenConfiguration
The OIDC configuration for processing access tokens. Contains allowed audience claims, for example ‘auth.example.com`, and the claim that you want to map to the principal, for example `sub`.
4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4096 class OpenIdConnectTokenSelection < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < OpenIdConnectTokenSelection; end class IdentityTokenOnly < OpenIdConnectTokenSelection; end class Unknown < OpenIdConnectTokenSelection; end end |
#boolean ⇒ Boolean
A Cedar tag value of [Boolean] type.
Example: ‘false`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-bool
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#cedar_json ⇒ String
A JSON string representation of the schema supported by applications that use this policy store. To delete the schema, run [PutSchema] with ‘{}` for this parameter. For more information, see [Policy store schema] in the *Amazon Verified Permissions User Guide*.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_PutSchema.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/userguide/schema.html
1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1264 class ContextDefinition < Struct.new( :context_map, :cedar_json, :unknown) SENSITIVE = [:context_map, :cedar_json] include Aws::Structure include Aws::Structure::Union class ContextMap < ContextDefinition; end class CedarJson < ContextDefinition; end class Unknown < ContextDefinition; end end |
#cognito_user_pool_configuration ⇒ Types::UpdateCognitoUserPoolConfiguration
Contains configuration details of a Amazon Cognito user pool.
1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1081 class Configuration < Struct.new( :cognito_user_pool_configuration, :open_id_connect_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CognitoUserPoolConfiguration < Configuration; end class OpenIdConnectConfiguration < Configuration; end class Unknown < Configuration; end end |
#context_map ⇒ Hash<String,Types::AttributeValue>
An list of attributes that are needed to successfully evaluate an authorization request. Each attribute in this array must include a map of a data type and its value.
Example: ‘“contextMap”:“<KeyName1>”:{“boolean”:true,“<KeyName2>”:“long”:1234}`
1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1264 class ContextDefinition < Struct.new( :context_map, :cedar_json, :unknown) SENSITIVE = [:context_map, :cedar_json] include Aws::Structure include Aws::Structure::Union class ContextMap < ContextDefinition; end class CedarJson < ContextDefinition; end class Unknown < ContextDefinition; end end |
#datetime ⇒ String
A Cedar tag value of [datetime] type.
Example: ‘“2025-11-04T11:35:00.000+0100”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-datetime
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#decimal ⇒ String
A Cedar tag value of [decimal] type.
Example: ‘“-2.0”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-decimal
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#default ⇒ Types::Unit
This is the default encryption state. The policy store is encrypted using an Amazon Web Services owned key.
2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2005 class EncryptionSettings < Struct.new( :kms_encryption_settings, :default, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsEncryptionSettings < EncryptionSettings; end class Default < EncryptionSettings; end class Unknown < EncryptionSettings; end end |
#duration ⇒ String
A Cedar tag value of [duration] type.
Example: ‘“-1d12h”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-duration
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#entity_identifier ⇒ Types::EntityIdentifier
A Cedar tag value of type [EntityIdentifier].
Example: ‘{ “entityId”: “alice”, “entityType”: “User” }`
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_EntityIdentifier.html
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#entity_list ⇒ Array<Types::EntityItem>
An array of entities that are needed to successfully evaluate an authorization request. Each entity in this array must include an identifier for the entity, the attributes of the entity, and a list of any parent entities.
<note markdown=“1”> If you include multiple entities with the same ‘identifier`, only the last one is processed in the request.
</note>
2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2092 class EntitiesDefinition < Struct.new( :entity_list, :cedar_json, :unknown) SENSITIVE = [:cedar_json] include Aws::Structure include Aws::Structure::Union class EntityList < EntitiesDefinition; end class CedarJson < EntitiesDefinition; end class Unknown < EntitiesDefinition; end end |
#identifier ⇒ Types::EntityIdentifier
The identifier of the entity. It can consist of either an EntityType and EntityId, a principal, or a resource.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2216 class EntityReference < Struct.new( :unspecified, :identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Unspecified < EntityReference; end class Identifier < EntityReference; end class Unknown < EntityReference; end end |
#identity_token_only ⇒ Types::UpdateOpenIdConnectIdentityTokenConfiguration
The OIDC configuration for processing identity (ID) tokens. Contains allowed client ID claims, for example ‘1example23456789`, and the claim that you want to map to the principal, for example `sub`.
4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4096 class OpenIdConnectTokenSelection < Struct.new( :access_token_only, :identity_token_only, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessTokenOnly < OpenIdConnectTokenSelection; end class IdentityTokenOnly < OpenIdConnectTokenSelection; end class Unknown < OpenIdConnectTokenSelection; end end |
#ipaddr ⇒ String
A Cedar tag value of [ipaddr] type.
Example: ‘“10.50.0.0/24”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-ipaddr
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#kms_encryption_settings ⇒ Types::KmsEncryptionSettings
The KMS encryption settings for this policy store to encrypt data with. It will contain the customer-managed KMS key, and a user-defined encryption context.
2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2005 class EncryptionSettings < Struct.new( :kms_encryption_settings, :default, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsEncryptionSettings < EncryptionSettings; end class Default < EncryptionSettings; end class Unknown < EncryptionSettings; end end |
#kms_encryption_state ⇒ Types::KmsEncryptionState
The KMS encryption settings currently configured for this policy store to encrypt data with. It contains the customer-managed KMS key, and a user-defined encryption context.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2043 class EncryptionState < Struct.new( :kms_encryption_state, :default, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsEncryptionState < EncryptionState; end class Default < EncryptionState; end class Unknown < EncryptionState; end end |
#long ⇒ Integer
A Cedar tag value of [Long] type.
Example: ‘0`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-long
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#open_id_connect_configuration ⇒ Types::UpdateOpenIdConnectConfiguration
Contains configuration details of an OpenID Connect (OIDC) identity provider, or identity source, that Verified Permissions can use to generate entities from authenticated identities. It specifies the issuer URL, token type that you want to use, and policy store entity details.
1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1081 class Configuration < Struct.new( :cognito_user_pool_configuration, :open_id_connect_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CognitoUserPoolConfiguration < Configuration; end class OpenIdConnectConfiguration < Configuration; end class Unknown < Configuration; end end |
#record ⇒ Hash<String,Types::CedarTagValue>
A Cedar tag value of [Record] type.
Example: ‘{ “keyName”: { } }`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-record
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#set ⇒ Array<Types::CedarTagValue>
A Cedar tag value of [Set] type.
Example: ‘{“set”: [ { “string”: “abc” } ] }`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-set
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#static ⇒ Types::UpdateStaticPolicyDefinition
Contains details about the updates to be applied to a static policy.
4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4224 class PolicyDefinition < Struct.new( :static, :template_linked, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Static < PolicyDefinition; end class TemplateLinked < PolicyDefinition; end class Unknown < PolicyDefinition; end end |
#string ⇒ String
A Cedar tag value of [String] type.
Example: ‘“abc”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-string
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#template_linked ⇒ Types::TemplateLinkedPolicyDefinitionItem
Information about a template-linked policy that was created by instantiating a policy template.
4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4224 class PolicyDefinition < Struct.new( :static, :template_linked, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Static < PolicyDefinition; end class TemplateLinked < PolicyDefinition; end class Unknown < PolicyDefinition; end end |
#unspecified ⇒ Boolean
Used to indicate that a principal or resource is not specified. This can be used to search for policies that are not associated with a specific principal or resource.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2216 class EntityReference < Struct.new( :unspecified, :identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Unspecified < EntityReference; end class Identifier < EntityReference; end class Unknown < EntityReference; end end |