Class: Aws::VerifiedPermissions::Types::AttributeValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::AttributeValue
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
AttributeValue is a union - when making an API calls you must set exactly one of the members.
AttributeValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AttributeValue corresponding to the set member.
The value of an attribute.
Contains information about the runtime context for a request for which an authorization decision is made.
This data type is used as a member of the [ContextDefinition] structure which is used as a request parameter for the [IsAuthorized], [BatchIsAuthorized], and
- IsAuthorizedWithToken][4
-
operations.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ContextDefinition.html [2]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorized.html [3]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_BatchIsAuthorized.html [4]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_IsAuthorizedWithToken.html
Direct Known Subclasses
Boolean, Datetime, Decimal, Duration, EntityIdentifier, Ipaddr, Long, Record, Set, String, Unknown
Defined Under Namespace
Classes: Boolean, Datetime, Decimal, Duration, EntityIdentifier, Ipaddr, Long, Record, Set, String, Unknown
Constant Summary collapse
- SENSITIVE =
[:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration]
Instance Attribute Summary collapse
-
#boolean ⇒ Boolean
An attribute value of [Boolean] type.
-
#datetime ⇒ String
An attribute value of [datetime] type.
-
#decimal ⇒ String
An attribute value of [decimal] type.
-
#duration ⇒ String
An attribute value of [duration] type.
-
#entity_identifier ⇒ Types::EntityIdentifier
An attribute value of type [EntityIdentifier].
-
#ipaddr ⇒ String
An attribute value of [ipaddr] type.
-
#long ⇒ Integer
An attribute value of [Long] type.
-
#record ⇒ Hash<String,Types::AttributeValue>
An attribute value of [Record] type.
-
#set ⇒ Array<Types::AttributeValue>
An attribute value of [Set] type.
-
#string ⇒ String
An attribute value of [String] type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#boolean ⇒ Boolean
An attribute value of [Boolean] type.
Example: ‘true`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-bool
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#datetime ⇒ String
An attribute value of [datetime] type.
Example: ‘“2024-10-15T11:35:00Z”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-datetime
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#decimal ⇒ String
An attribute value of [decimal] type.
Example: ‘“1.1”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-decimal
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#duration ⇒ String
An attribute value of [duration] type.
Example: ‘“1h30m”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-duration
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#entity_identifier ⇒ Types::EntityIdentifier
An attribute value of type [EntityIdentifier].
Example: ‘{ “entityId”: “alice”, “entityType”: “User” }`
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_EntityIdentifier.html
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#ipaddr ⇒ String
An attribute value of [ipaddr] type.
Example: ‘“192.168.1.100”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-ipaddr
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#long ⇒ Integer
An attribute value of [Long] type.
Example: ‘0`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-long
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#record ⇒ Hash<String,Types::AttributeValue>
An attribute value of [Record] type.
Example: ‘{ “keyName”: { } }`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-record
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#set ⇒ Array<Types::AttributeValue>
An attribute value of [Set] type.
Example: ‘[ { ] }`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-set
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#string ⇒ String
An attribute value of [String] type.
Example: ‘“abc”`
[1]: docs.cedarpolicy.com/policies/syntax-datatypes.html#datatype-string
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 class AttributeValue < Struct.new( :boolean, :entity_identifier, :long, :string, :set, :record, :ipaddr, :decimal, :datetime, :duration, :unknown) SENSITIVE = [:boolean, :long, :string, :ipaddr, :decimal, :datetime, :duration] include Aws::Structure include Aws::Structure::Union class Boolean < AttributeValue; end class EntityIdentifier < AttributeValue; end class Long < AttributeValue; end class String < AttributeValue; end class Set < AttributeValue; end class Record < AttributeValue; end class Ipaddr < AttributeValue; end class Decimal < AttributeValue; end class Datetime < AttributeValue; end class Duration < AttributeValue; end class Unknown < AttributeValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
182 183 184 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 182 def unknown @unknown end |