Class: Aws::VerifiedPermissions::Types::CreatePolicyStoreAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::CreatePolicyStoreAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
Specifies the name of the policy store alias to create.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store to associate with the alias.
Instance Attribute Details
#alias_name ⇒ String
Specifies the name of the policy store alias to create. The name must be unique within your Amazon Web Services account and Amazon Web Services Region.
policy-store-alias/.
1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1528 class CreatePolicyStoreAliasInput < Struct.new( :alias_name, :policy_store_id) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store to associate with the alias.
1528 1529 1530 1531 1532 1533 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1528 class CreatePolicyStoreAliasInput < Struct.new( :alias_name, :policy_store_id) SENSITIVE = [] include Aws::Structure end |