Class: Aws::VerifiedPermissions::Types::DeletePolicyStoreAliasInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_nameString

Specifies the name of the policy store alias that you want to delete.

<note markdown=“1”> The alias name must always be prefixed with ‘policy-store-alias/`.

</note>

Returns:

  • (String)


1864
1865
1866
1867
1868
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1864

class DeletePolicyStoreAliasInput < Struct.new(
  :alias_name)
  SENSITIVE = []
  include Aws::Structure
end