Class: Aws::VerifiedPermissions::Types::DeletePolicyStoreAliasInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::DeletePolicyStoreAliasInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
Specifies the name of the policy store alias that you want to delete.
Instance Attribute Details
#alias_name ⇒ String
Specifies the name of the policy store alias that you want to delete.
<note markdown=“1”> The alias name must always be prefixed with ‘policy-store-alias/`.
</note>
1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 1864 class DeletePolicyStoreAliasInput < Struct.new( :alias_name) SENSITIVE = [] include Aws::Structure end |