Class: Aws::VerifiedPermissions::Types::GetPolicyOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::ActionIdentifier>

The action that a policy permits or forbids. For example, ‘[{“actionId”: “ViewPhoto”, “actionType”: “PhotoFlash::Action”, “SharePhoto”, “entityType”: “PhotoFlash::Action”]}`.

Returns:



2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date and time that the policy was originally created.

Returns:

  • (Time)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#definitionTypes::PolicyDefinitionDetail

The definition of the requested policy.



2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#effectString

The effect of the decision that a policy returns to an authorization request. For example, ‘“effect”: “Permit”`.

Returns:

  • (String)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_dateTime

The date and time that the policy was last updated.

Returns:

  • (Time)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the policy, if one was assigned when the policy was created or last updated.

Returns:

  • (String)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#policy_idString

The unique ID of the policy that you want information about.

Returns:

  • (String)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

The ID of the policy store that contains the policy that you want information about.

Returns:

  • (String)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#policy_typeString

The type of the policy.

Returns:

  • (String)


2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#principalTypes::EntityIdentifier

The principal specified in the policy’s scope. This element isn’t included in the response when ‘Principal` isn’t present in the policy content.



2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#resourceTypes::EntityIdentifier

The resource specified in the policy’s scope. This element isn’t included in the response when ‘Resource` isn’t present in the policy content.



2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2408

class GetPolicyOutput < Struct.new(
  :policy_store_id,
  :policy_id,
  :policy_type,
  :principal,
  :resource,
  :actions,
  :definition,
  :created_date,
  :last_updated_date,
  :effect,
  :name)
  SENSITIVE = []
  include Aws::Structure
end