Class: Aws::VerifiedPermissions::Types::GetPolicyStoreAliasOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_arnString

The Amazon Resource Name (ARN) of the policy store alias.

Returns:

  • (String)


2467
2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2467

class GetPolicyStoreAliasOutput < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#alias_nameString

The name of the policy store alias.

Returns:

  • (String)


2467
2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2467

class GetPolicyStoreAliasOutput < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the policy store alias was created.

Returns:

  • (Time)


2467
2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2467

class GetPolicyStoreAliasOutput < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#policy_store_idString

The ID of the policy store associated with the alias.

Returns:

  • (String)


2467
2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2467

class GetPolicyStoreAliasOutput < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the policy store alias. Policy Store Aliases in the Active state can be used normally. When a policy store alias is deleted, it enters the PendingDeletion state. Policy Store Aliases in the PendingDeletion cannot be used, and creating a policy store alias with the same alias name will fail.

Returns:

  • (String)


2467
2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2467

class GetPolicyStoreAliasOutput < Struct.new(
  :alias_name,
  :policy_store_id,
  :alias_arn,
  :created_at,
  :state)
  SENSITIVE = []
  include Aws::Structure
end