Class: Aws::VerifiedPermissions::Types::GetPolicyStoreInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-verifiedpermissions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_store_idString

Specifies the policy store that you want information about.

To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:

  • ID: ‘PSEXAMPLEabcdefg111111`

  • Alias name: ‘policy-store-alias/example-policy-store`

To view aliases, use [ListPolicyStoreAliases].

[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html

Returns:

  • (String)


2508
2509
2510
2511
2512
2513
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2508

class GetPolicyStoreInput < Struct.new(
  :policy_store_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsBoolean

Specifies whether to return the tags that are attached to the policy store. If this parameter is included in the API call, the tags are returned, otherwise they are not returned.

<note markdown=“1”> If this parameter is included in the API call but there are no tags attached to the policy store, the ‘tags` response parameter is omitted from the response.

</note>

Returns:

  • (Boolean)


2508
2509
2510
2511
2512
2513
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2508

class GetPolicyStoreInput < Struct.new(
  :policy_store_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end