Class: Aws::VerifiedPermissions::Types::GetPolicyStoreOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::GetPolicyStoreOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the policy store.
-
#cedar_version ⇒ String
The version of the Cedar language used with policies, policy templates, and schemas in this policy store.
-
#created_date ⇒ Time
The date and time that the policy store was originally created.
-
#deletion_protection ⇒ String
Specifies whether the policy store can be deleted.
-
#description ⇒ String
Descriptive text that you can provide to help with identification of the current policy store.
-
#encryption_state ⇒ Types::EncryptionState
A structure that contains the encryption configuration for the policy store.
-
#last_updated_date ⇒ Time
The date and time that the policy store was last updated.
-
#policy_store_id ⇒ String
The ID of the policy store;.
-
#tags ⇒ Hash<String,String>
The list of tags associated with the policy store.
-
#validation_settings ⇒ Types::ValidationSettings
The current validation settings for the policy store.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the policy store.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#cedar_version ⇒ String
The version of the Cedar language used with policies, policy templates, and schemas in this policy store. For more information, see Amazon Verified Permissions upgrade to Cedar v4 FAQ.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#created_date ⇒ Time
The date and time that the policy store was originally created.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#deletion_protection ⇒ String
Specifies whether the policy store can be deleted. If enabled, the policy store can't be deleted.
The default state is DISABLED.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
Descriptive text that you can provide to help with identification of the current policy store.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#encryption_state ⇒ Types::EncryptionState
A structure that contains the encryption configuration for the policy store.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#last_updated_date ⇒ Time
The date and time that the policy store was last updated.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the policy store;
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tags associated with the policy store.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |
#validation_settings ⇒ Types::ValidationSettings
The current validation settings for the policy store.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2581 class GetPolicyStoreOutput < Struct.new( :policy_store_id, :arn, :validation_settings, :created_date, :last_updated_date, :description, :deletion_protection, :encryption_state, :cedar_version, :tags) SENSITIVE = [:description] include Aws::Structure end |