Class: Aws::VerifiedPermissions::Types::GetPolicyTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::GetPolicyTemplateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy template that you want information about.
-
#policy_template_id ⇒ String
Specifies the ID of the policy template that you want information about.
Instance Attribute Details
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy template that you want information about.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
2615 2616 2617 2618 2619 2620 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2615 class GetPolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id) SENSITIVE = [] include Aws::Structure end |
#policy_template_id ⇒ String
Specifies the ID of the policy template that you want information about.
You can use the policy template name in place of the policy template ID. When using a name, prefix it with ‘name/`. For example:
-
ID: ‘PTEXAMPLEabcdefg111111`
-
Name: ‘name/example-policy-template`
2615 2616 2617 2618 2619 2620 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2615 class GetPolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id) SENSITIVE = [] include Aws::Structure end |