Class: Aws::VerifiedPermissions::Types::IsAuthorizedInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::IsAuthorizedInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ Types::ActionIdentifier
Specifies the requested action to be authorized.
-
#context ⇒ Types::ContextDefinition
Specifies additional context that can be used to make more granular authorization decisions.
-
#entities ⇒ Types::EntitiesDefinition
(Optional) Specifies the list of resources and principals and their associated attributes that Verified Permissions can examine when evaluating the policies.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store.
-
#principal ⇒ Types::EntityIdentifier
Specifies the principal for which the authorization decision is to be made.
-
#resource ⇒ Types::EntityIdentifier
Specifies the resource for which the authorization decision is to be made.
Instance Attribute Details
#action ⇒ Types::ActionIdentifier
Specifies the requested action to be authorized. For example, is the principal authorized to perform this action on the resource?
2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2985 class IsAuthorizedInput < Struct.new( :policy_store_id, :principal, :action, :resource, :context, :entities) SENSITIVE = [] include Aws::Structure end |
#context ⇒ Types::ContextDefinition
Specifies additional context that can be used to make more granular authorization decisions.
2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2985 class IsAuthorizedInput < Struct.new( :policy_store_id, :principal, :action, :resource, :context, :entities) SENSITIVE = [] include Aws::Structure end |
#entities ⇒ Types::EntitiesDefinition
(Optional) Specifies the list of resources and principals and their associated attributes that Verified Permissions can examine when evaluating the policies. These additional entities and their attributes can be referenced and checked by conditional elements in the policies in the specified policy store.
<note markdown=“1”> You can include only principal and resource entities in this parameter; you can’t include actions. You must specify actions in the schema.
</note>
2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2985 class IsAuthorizedInput < Struct.new( :policy_store_id, :principal, :action, :resource, :context, :entities) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store. Policies in this policy store will be used to make an authorization decision for the input.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2985 class IsAuthorizedInput < Struct.new( :policy_store_id, :principal, :action, :resource, :context, :entities) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ Types::EntityIdentifier
Specifies the principal for which the authorization decision is to be made.
2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2985 class IsAuthorizedInput < Struct.new( :policy_store_id, :principal, :action, :resource, :context, :entities) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::EntityIdentifier
Specifies the resource for which the authorization decision is to be made.
2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 2985 class IsAuthorizedInput < Struct.new( :policy_store_id, :principal, :action, :resource, :context, :entities) SENSITIVE = [] include Aws::Structure end |