Class: Aws::VerifiedPermissions::Types::IsAuthorizedWithTokenInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::IsAuthorizedWithTokenInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:identity_token, :access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
Specifies an access token for the principal to be authorized.
-
#action ⇒ Types::ActionIdentifier
Specifies the requested action to be authorized.
-
#context ⇒ Types::ContextDefinition
Specifies additional context that can be used to make more granular authorization decisions.
-
#entities ⇒ Types::EntitiesDefinition
(Optional) Specifies the list of resources and their associated attributes that Verified Permissions can examine when evaluating the policies.
-
#identity_token ⇒ String
Specifies an identity token for the principal to be authorized.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store.
-
#resource ⇒ Types::EntityIdentifier
Specifies the resource for which the authorization decision is made.
Instance Attribute Details
#access_token ⇒ String
Specifies an access token for the principal to be authorized. This token is provided to you by the identity provider (IdP) associated with the specified identity source. You must specify either an ‘accessToken`, an `identityToken`, or both.
Must be an access token. Verified Permissions returns an error if the ‘token_use` claim in the submitted token isn’t ‘access`.
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |
#action ⇒ Types::ActionIdentifier
Specifies the requested action to be authorized. Is the specified principal authorized to perform this action on the specified resource.
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |
#context ⇒ Types::ContextDefinition
Specifies additional context that can be used to make more granular authorization decisions.
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |
#entities ⇒ Types::EntitiesDefinition
(Optional) Specifies the list of resources and their associated attributes that Verified Permissions can examine when evaluating the policies. These additional entities and their attributes can be referenced and checked by conditional elements in the policies in the specified policy store.
You can’t include principals in this parameter, only resource and action entities. This parameter can’t include any entities of a type that matches the user or group entity types that you defined in your identity source.
* The `IsAuthorizedWithToken` operation takes principal attributes
from <b> <i>only</i> </b> the `identityToken` or `accessToken`
passed to the operation.
-
For action entities, you can include only their ‘Identifier` and `EntityType`.
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |
#identity_token ⇒ String
Specifies an identity token for the principal to be authorized. This token is provided to you by the identity provider (IdP) associated with the specified identity source. You must specify either an ‘accessToken`, an `identityToken`, or both.
Must be an ID token. Verified Permissions returns an error if the ‘token_use` claim in the submitted token isn’t ‘id`.
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store. Policies in this policy store will be used to make an authorization decision for the input.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |
#resource ⇒ Types::EntityIdentifier
Specifies the resource for which the authorization decision is made. For example, is the principal allowed to perform the action on the resource?
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 3104 class IsAuthorizedWithTokenInput < Struct.new( :policy_store_id, :identity_token, :access_token, :action, :resource, :context, :entities) SENSITIVE = [:identity_token, :access_token] include Aws::Structure end |