Class: Aws::VerifiedPermissions::Types::PolicyStoreAliasItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::PolicyStoreAliasItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Contains information about a policy store alias.
This data type is used as a response parameter for the
- ListPolicyStoreAliases][1
-
operation.
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_arn ⇒ String
The Amazon Resource Name (ARN) of the policy store alias.
-
#alias_name ⇒ String
The name of the policy store alias.
-
#created_at ⇒ Time
The date and time the policy store alias was created.
-
#policy_store_id ⇒ String
The ID of the policy store associated with the alias.
-
#state ⇒ String
The state of the policy store alias.
Instance Attribute Details
#alias_arn ⇒ String
The Amazon Resource Name (ARN) of the policy store alias.
4471 4472 4473 4474 4475 4476 4477 4478 4479 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471 class PolicyStoreAliasItem < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#alias_name ⇒ String
The name of the policy store alias.
4471 4472 4473 4474 4475 4476 4477 4478 4479 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471 class PolicyStoreAliasItem < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the policy store alias was created.
4471 4472 4473 4474 4475 4476 4477 4478 4479 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471 class PolicyStoreAliasItem < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
The ID of the policy store associated with the alias.
4471 4472 4473 4474 4475 4476 4477 4478 4479 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471 class PolicyStoreAliasItem < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the policy store alias. Policy Store Aliases in the Active state can be used normally. When a policy store alias is deleted, it enters the PendingDeletion state. Policy Store Aliases in the PendingDeletion state cannot be used, and creating a policy store alias with the same alias name will fail.
4471 4472 4473 4474 4475 4476 4477 4478 4479 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 4471 class PolicyStoreAliasItem < Struct.new( :alias_name, :policy_store_id, :alias_arn, :created_at, :state) SENSITIVE = [] include Aws::Structure end |