Class: Aws::VerifiedPermissions::Types::UpdateIdentitySourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::UpdateIdentitySourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:principal_entity_type]
Instance Attribute Summary collapse
-
#identity_source_id ⇒ String
Specifies the ID of the identity source that you want to update.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the identity source that you want to update.
-
#principal_entity_type ⇒ String
Specifies the data type of principals generated for identities authenticated by the identity source.
-
#update_configuration ⇒ Types::UpdateConfiguration
Specifies the details required to communicate with the identity provider (IdP) associated with this identity source.
Instance Attribute Details
#identity_source_id ⇒ String
Specifies the ID of the identity source that you want to update.
5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121 class UpdateIdentitySourceInput < Struct.new( :policy_store_id, :identity_source_id, :update_configuration, :principal_entity_type) SENSITIVE = [:principal_entity_type] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the identity source that you want to update.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121 class UpdateIdentitySourceInput < Struct.new( :policy_store_id, :identity_source_id, :update_configuration, :principal_entity_type) SENSITIVE = [:principal_entity_type] include Aws::Structure end |
#principal_entity_type ⇒ String
Specifies the data type of principals generated for identities authenticated by the identity source.
5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121 class UpdateIdentitySourceInput < Struct.new( :policy_store_id, :identity_source_id, :update_configuration, :principal_entity_type) SENSITIVE = [:principal_entity_type] include Aws::Structure end |
#update_configuration ⇒ Types::UpdateConfiguration
Specifies the details required to communicate with the identity provider (IdP) associated with this identity source.
5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5121 class UpdateIdentitySourceInput < Struct.new( :policy_store_id, :identity_source_id, :update_configuration, :principal_entity_type) SENSITIVE = [:principal_entity_type] include Aws::Structure end |