Class: Aws::VerifiedPermissions::Types::UpdatePolicyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::UpdatePolicyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definition ⇒ Types::UpdatePolicyDefinition
Specifies the updated policy content that you want to replace on the specified policy.
-
#name ⇒ String
Specifies a name for the policy that is unique among all policies within the policy store.
-
#policy_id ⇒ String
Specifies the ID of the policy that you want to update.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy that you want to update.
Instance Attribute Details
#definition ⇒ Types::UpdatePolicyDefinition
Specifies the updated policy content that you want to replace on the specified policy. The content must be valid Cedar policy language text.
If you don’t specify this parameter, the existing policy definition remains unchanged.
You can change only the following elements from the policy definition:
-
The ‘action` referenced by the policy.
-
Any conditional clauses, such as ‘when` or `unless` clauses.
You **can’t** change the following elements:
-
Changing from ‘static` to `templateLinked`.
-
Changing the effect of the policy from ‘permit` or `forbid`.
-
The ‘principal` referenced by the policy.
-
The ‘resource` referenced by the policy.
5458 5459 5460 5461 5462 5463 5464 5465 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5458 class UpdatePolicyInput < Struct.new( :policy_store_id, :policy_id, :definition, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies a name for the policy that is unique among all policies within the policy store. You can use the name in place of the policy ID in API operations that reference the policy. The name must be prefixed with ‘name/`.
<note markdown=“1”> If you don’t include the name in an update request, the existing name is unchanged. To remove a name, set it to an empty string (‘“”`).
</note>
If you specify a name that is already associated with another policy in the policy store, you receive a ‘ConflictException` error.
5458 5459 5460 5461 5462 5463 5464 5465 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5458 class UpdatePolicyInput < Struct.new( :policy_store_id, :policy_id, :definition, :name) SENSITIVE = [] include Aws::Structure end |
#policy_id ⇒ String
Specifies the ID of the policy that you want to update. To find this value, you can use [ListPolicies].
You can use the policy name in place of the policy ID. When using a name, prefix it with ‘name/`. For example:
-
ID: ‘SPEXAMPLEabcdefg111111`
-
Name: ‘name/example-policy`
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicies.html
5458 5459 5460 5461 5462 5463 5464 5465 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5458 class UpdatePolicyInput < Struct.new( :policy_store_id, :policy_id, :definition, :name) SENSITIVE = [] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy that you want to update.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
5458 5459 5460 5461 5462 5463 5464 5465 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5458 class UpdatePolicyInput < Struct.new( :policy_store_id, :policy_id, :definition, :name) SENSITIVE = [] include Aws::Structure end |