Class: Aws::VerifiedPermissions::Types::UpdatePolicyStoreInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::UpdatePolicyStoreInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#deletion_protection ⇒ String
Specifies whether the policy store can be deleted.
-
#description ⇒ String
Descriptive text that you can provide to help with identification of the current policy store.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that you want to update.
-
#validation_settings ⇒ Types::ValidationSettings
A structure that defines the validation settings that want to enable for the policy store.
Instance Attribute Details
#deletion_protection ⇒ String
Specifies whether the policy store can be deleted. If enabled, the policy store can't be deleted.
When you call UpdatePolicyStore, this parameter is unchanged
unless explicitly included in the call.
5578 5579 5580 5581 5582 5583 5584 5585 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5578 class UpdatePolicyStoreInput < Struct.new( :policy_store_id, :validation_settings, :deletion_protection, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
Descriptive text that you can provide to help with identification of the current policy store.
5578 5579 5580 5581 5582 5583 5584 5585 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5578 class UpdatePolicyStoreInput < Struct.new( :policy_store_id, :validation_settings, :deletion_protection, :description) SENSITIVE = [:description] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store that you want to update
To specify a policy store, use its ID or alias name. When using an
alias name, prefix it with policy-store-alias/. For example:
-
ID:
PSEXAMPLEabcdefg111111 -
Alias name:
policy-store-alias/example-policy-store
To view aliases, use ListPolicyStoreAliases.
5578 5579 5580 5581 5582 5583 5584 5585 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5578 class UpdatePolicyStoreInput < Struct.new( :policy_store_id, :validation_settings, :deletion_protection, :description) SENSITIVE = [:description] include Aws::Structure end |
#validation_settings ⇒ Types::ValidationSettings
A structure that defines the validation settings that want to enable for the policy store.
5578 5579 5580 5581 5582 5583 5584 5585 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5578 class UpdatePolicyStoreInput < Struct.new( :policy_store_id, :validation_settings, :deletion_protection, :description) SENSITIVE = [:description] include Aws::Structure end |