Class: Aws::VerifiedPermissions::Types::UpdatePolicyTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::VerifiedPermissions::Types::UpdatePolicyTemplateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-verifiedpermissions/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :statement]
Instance Attribute Summary collapse
-
#description ⇒ String
Specifies a new description to apply to the policy template.
-
#name ⇒ String
Specifies a name for the policy template that is unique among all policy templates within the policy store.
-
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy template that you want to update.
-
#policy_template_id ⇒ String
Specifies the ID of the policy template that you want to update.
-
#statement ⇒ String
Specifies new statement content written in Cedar policy language to replace the current body of the policy template.
Instance Attribute Details
#description ⇒ String
Specifies a new description to apply to the policy template.
5676 5677 5678 5679 5680 5681 5682 5683 5684 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5676 class UpdatePolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#name ⇒ String
Specifies a name for the policy template that is unique among all policy templates within the policy store. You can use the name in place of the policy template ID in API operations that reference the policy template. The name must be prefixed with ‘name/`.
<note markdown=“1”> If you don’t include the name in an update request, the existing name is unchanged. To remove a name, set it to an empty string (‘“”`).
</note>
If you specify a name that is already associated with another policy template in the policy store, you receive a ‘ConflictException` error.
5676 5677 5678 5679 5680 5681 5682 5683 5684 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5676 class UpdatePolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#policy_store_id ⇒ String
Specifies the ID of the policy store that contains the policy template that you want to update.
To specify a policy store, use its ID or alias name. When using an alias name, prefix it with ‘policy-store-alias/`. For example:
-
ID: ‘PSEXAMPLEabcdefg111111`
-
Alias name: ‘policy-store-alias/example-policy-store`
To view aliases, use [ListPolicyStoreAliases].
[1]: docs.aws.amazon.com/verifiedpermissions/latest/apireference/API_ListPolicyStoreAliases.html
5676 5677 5678 5679 5680 5681 5682 5683 5684 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5676 class UpdatePolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#policy_template_id ⇒ String
Specifies the ID of the policy template that you want to update.
You can use the policy template name in place of the policy template ID. When using a name, prefix it with ‘name/`. For example:
-
ID: ‘PTEXAMPLEabcdefg111111`
-
Name: ‘name/example-policy-template`
5676 5677 5678 5679 5680 5681 5682 5683 5684 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5676 class UpdatePolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |
#statement ⇒ String
Specifies new statement content written in Cedar policy language to replace the current body of the policy template.
You can change only the following elements of the policy body:
-
The ‘action` referenced by the policy template.
-
Any conditional clauses, such as ‘when` or `unless` clauses.
You **can’t** change the following elements:
-
The effect (‘permit` or `forbid`) of the policy template.
-
The ‘principal` referenced by the policy template.
-
The ‘resource` referenced by the policy template.
5676 5677 5678 5679 5680 5681 5682 5683 5684 |
# File 'lib/aws-sdk-verifiedpermissions/types.rb', line 5676 class UpdatePolicyTemplateInput < Struct.new( :policy_store_id, :policy_template_id, :description, :statement, :name) SENSITIVE = [:description, :statement] include Aws::Structure end |